@@ -95,13 +95,10 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * {@link SecurityOperations#getDelegationToken(DelegationTokenConfig)}, is not subject to this
    * concern.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param principal
-   *          a valid Accumulo user name (user must have Table.CREATE permission if
-   *          {@link #setCreateTables(Job, boolean)} is set to true)
-   * @param token
-   *          the user's password
+   * @param job the Hadoop job instance to be configured
+   * @param principal a valid Accumulo user name (user must have Table.CREATE permission if
+   *        {@link #setCreateTables(Job, boolean)} is set to true)
+   * @param token the user's password
    * @since 1.5.0
    */
   public static void setConnectorInfo(Job job, String principal, AuthenticationToken token)
@@ -140,13 +137,10 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * Stores the password in a file in HDFS and pulls that into the Distributed Cache in an attempt
    * to be more secure than storing it in the Configuration.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param principal
-   *          a valid Accumulo user name (user must have Table.CREATE permission if
-   *          {@link #setCreateTables(Job, boolean)} is set to true)
-   * @param tokenFile
-   *          the path to the token file
+   * @param job the Hadoop job instance to be configured
+   * @param principal a valid Accumulo user name (user must have Table.CREATE permission if
+   *        {@link #setCreateTables(Job, boolean)} is set to true)
+   * @param tokenFile the path to the token file
    * @since 1.6.0
    */
   public static void setConnectorInfo(Job job, String principal, String tokenFile)
@@ -157,8 +151,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Determines if the connector has been configured.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return true if the connector has been configured, false otherwise
    * @since 1.5.0
    * @see #setConnectorInfo(Job, String, AuthenticationToken)
@@ -170,8 +163,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Gets the user name from the configuration.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return the user name
    * @since 1.5.0
    * @see #setConnectorInfo(Job, String, AuthenticationToken)
@@ -206,8 +198,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * Gets the authenticated token from either the specified token file or directly from the
    * configuration, whichever was used when the job was configured.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return the principal's authentication token
    * @since 1.6.0
    * @see #setConnectorInfo(Job, String, AuthenticationToken)
@@ -222,12 +213,9 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Configures a {@link org.apache.accumulo.core.client.ZooKeeperInstance} for this job.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param instanceName
-   *          the Accumulo instance name
-   * @param zooKeepers
-   *          a comma-separated list of zookeeper servers
+   * @param job the Hadoop job instance to be configured
+   * @param instanceName the Accumulo instance name
+   * @param zooKeepers a comma-separated list of zookeeper servers
    * @since 1.5.0
    * @deprecated since 1.6.0; Use
    *             {@link #setZooKeeperInstance(Job, org.apache.accumulo.core.client.ClientConfiguration)}
@@ -242,11 +230,10 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Configures a {@link org.apache.accumulo.core.client.ZooKeeperInstance} for this job.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
+   * @param job the Hadoop job instance to be configured
    *
-   * @param clientConfig
-   *          client configuration for specifying connection timeouts, SSL connection options, etc.
+   * @param clientConfig client configuration for specifying connection timeouts, SSL connection
+   *        options, etc.
    * @since 1.6.0
    */
   public static void setZooKeeperInstance(Job job,
@@ -258,8 +245,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * Initializes an Accumulo {@link org.apache.accumulo.core.client.Instance} based on the
    * configuration.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return an Accumulo instance
    * @since 1.5.0
    */
@@ -270,10 +256,8 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Sets the log level for this job.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param level
-   *          the logging level
+   * @param job the Hadoop job instance to be configured
+   * @param level the logging level
    * @since 1.5.0
    */
   public static void setLogLevel(Job job, Level level) {
@@ -283,8 +267,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Gets the log level from this configuration.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return the log level
    * @since 1.5.0
    * @see #setLogLevel(Job, Level)
@@ -297,10 +280,8 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * Sets the default table name to use if one emits a null in place of a table name for a given
    * mutation. Table names can only be alpha-numeric and underscores.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param tableName
-   *          the table to use when the tablename is null in the write call
+   * @param job the Hadoop job instance to be configured
+   * @param tableName the table to use when the tablename is null in the write call
    * @since 1.5.0
    */
   public static void setDefaultTableName(Job job, String tableName) {
@@ -310,8 +291,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Gets the default table name from the configuration.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return the default table name
    * @since 1.5.0
    * @see #setDefaultTableName(Job, String)
@@ -325,10 +305,8 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * {@link BatchWriterConfig}, with sensible built-in defaults is used. Setting the configuration
    * multiple times overwrites any previous configuration.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param bwConfig
-   *          the configuration for the {@link BatchWriter}
+   * @param job the Hadoop job instance to be configured
+   * @param bwConfig the configuration for the {@link BatchWriter}
    * @since 1.5.0
    */
   public static void setBatchWriterOptions(Job job, BatchWriterConfig bwConfig) {
@@ -338,8 +316,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Gets the {@link BatchWriterConfig} settings.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return the configuration object
    * @since 1.5.0
    * @see #setBatchWriterOptions(Job, BatchWriterConfig)
@@ -355,10 +332,8 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * <p>
    * By default, this feature is <b>disabled</b>.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param enableFeature
-   *          the feature is enabled if true, disabled otherwise
+   * @param job the Hadoop job instance to be configured
+   * @param enableFeature the feature is enabled if true, disabled otherwise
    * @since 1.5.0
    */
   public static void setCreateTables(Job job, boolean enableFeature) {
@@ -368,8 +343,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Determines whether tables are permitted to be created as needed.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return true if the feature is disabled, false otherwise
    * @since 1.5.0
    * @see #setCreateTables(Job, boolean)
@@ -385,10 +359,8 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
    * <p>
    * By default, this feature is <b>disabled</b>.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param enableFeature
-   *          the feature is enabled if true, disabled otherwise
+   * @param job the Hadoop job instance to be configured
+   * @param enableFeature the feature is enabled if true, disabled otherwise
    * @since 1.5.0
    */
   public static void setSimulationMode(Job job, boolean enableFeature) {
@@ -398,8 +370,7 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
   /**
    * Determines whether this feature is enabled.
    *
-   * @param context
-   *          the Hadoop context for the configured job
+   * @param context the Hadoop context for the configured job
    * @return true if the feature is enabled, false otherwise
    * @since 1.5.0
    * @see #setSimulationMode(Job, boolean)
@@ -427,13 +398,15 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
     protected AccumuloRecordWriter(TaskAttemptContext context)
         throws AccumuloException, AccumuloSecurityException, IOException {
       Level l = getLogLevel(context);
-      if (l != null)
+      if (l != null) {
         log.setLevel(getLogLevel(context));
+      }
       this.simulate = getSimulationMode(context);
       this.createTables = canCreateTables(context);
 
-      if (simulate)
+      if (simulate) {
         log.info("Simulating output only. No writes to tables will occur");
+      }
 
       this.bws = new HashMap<>();
 
@@ -453,26 +426,30 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
      */
     @Override
     public void write(Text table, Mutation mutation) throws IOException {
-      if (table == null || table.toString().isEmpty())
+      if (table == null || table.toString().isEmpty()) {
         table = this.defaultTableName;
+      }
 
-      if (!simulate && table == null)
+      if (!simulate && table == null) {
         throw new IOException("No table or default table specified. Try simulation mode next time");
+      }
 
       ++mutCount;
       valCount += mutation.size();
       printMutation(table, mutation);
 
-      if (simulate)
+      if (simulate) {
         return;
+      }
 
-      if (!bws.containsKey(table))
+      if (!bws.containsKey(table)) {
         try {
           addTable(table);
         } catch (Exception e) {
           log.error("Could not add table '" + table + "'", e);
           throw new IOException(e);
         }
+      }
 
       try {
         bws.get(table).addMutation(mutation);
@@ -511,8 +488,9 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
         throw e;
       }
 
-      if (bw != null)
+      if (bw != null) {
         bws.put(tableName, bw);
+      }
     }
 
     private int printMutation(Text table, Mutation m) {
@@ -532,10 +510,11 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
     private String hexDump(byte[] ba) {
       StringBuilder sb = new StringBuilder();
       for (byte b : ba) {
-        if ((b > 0x20) && (b < 0x7e))
+        if ((b > 0x20) && (b < 0x7e)) {
           sb.append((char) b);
-        else
+        } else {
           sb.append(String.format("x%02x", b));
+        }
       }
       return sb.toString();
     }
@@ -543,8 +522,9 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
     @Override
     public void close(TaskAttemptContext attempt) throws IOException, InterruptedException {
       log.debug("mutations written: " + mutCount + ", values written: " + valCount);
-      if (simulate)
+      if (simulate) {
         return;
+      }
 
       try {
         mtbw.close();
@@ -568,14 +548,16 @@ public class AccumuloOutputFormat extends OutputFormat<Text,Mutation> {
 
   @Override
   public void checkOutputSpecs(JobContext job) throws IOException {
-    if (!isConnectorInfoSet(job))
+    if (!isConnectorInfoSet(job)) {
       throw new IOException("Connector info has not been set.");
+    }
     String principal = getPrincipal(job);
     AuthenticationToken token = getAuthenticationToken(job);
     try {
       AccumuloClient c = OutputConfigurator.client(CLASS, job.getConfiguration());
-      if (!c.securityOperations().authenticateUser(principal, token))
+      if (!c.securityOperations().authenticateUser(principal, token)) {
         throw new IOException("Unable to authenticate user");
+      }
     } catch (AccumuloException | AccumuloSecurityException e) {
       throw new IOException(e);
     }
