@@ -19,6 +19,7 @@
 package org.apache.accumulo.core.clientImpl;
 
 import static com.google.common.base.Preconditions.checkArgument;
+import static com.google.common.base.Suppliers.memoizeWithExpiration;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.Objects.requireNonNull;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
@@ -159,11 +160,6 @@ public class ClientContext implements AccumuloClient {
     }
   }
 
-  private static <T> Supplier<T> memoizeWithExpiration(Supplier<T> s) {
-    // This insanity exists to make modernizer plugin happy. We are living in the future now.
-    return () -> Suppliers.memoizeWithExpiration(s::get, 100, MILLISECONDS).get();
-  }
-
   private ScanServerSelector createScanServerSelector() {
     String clazz = ClientProperty.SCAN_SERVER_SELECTOR.getValue(info.getProperties());
     try {
@@ -231,11 +227,13 @@ public class ClientContext implements AccumuloClient {
         new ZooCacheFactory().getZooCache(info.getZooKeepers(), info.getZooKeepersSessionTimeOut());
     this.serverConf = serverConf;
     timeoutSupplier = memoizeWithExpiration(
-        () -> getConfiguration().getTimeInMillis(Property.GENERAL_RPC_TIMEOUT));
+        () -> getConfiguration().getTimeInMillis(Property.GENERAL_RPC_TIMEOUT), 100, MILLISECONDS);
     sslSupplier = Suppliers.memoize(() -> SslConnectionParams.forClient(getConfiguration()));
     saslSupplier = memoizeWithExpiration(
-        () -> SaslConnectionParams.from(getConfiguration(), getCredentials().getToken()));
-    scanServerSelectorSupplier = memoizeWithExpiration(() -> createScanServerSelector());
+        () -> SaslConnectionParams.from(getConfiguration(), getCredentials().getToken()), 100,
+        MILLISECONDS);
+    scanServerSelectorSupplier =
+        memoizeWithExpiration(this::createScanServerSelector, 100, MILLISECONDS);
     this.singletonReservation = Objects.requireNonNull(reservation);
     this.tableops = new TableOperationsImpl(this);
     this.namespaceops = new NamespaceOperationsImpl(this, tableops);
@@ -683,21 +681,24 @@ public class ClientContext implements AccumuloClient {
   // use cases overlap with requireNotDeleted, but this throws a checked exception
   public TableId requireTableExists(TableId tableId, String tableName)
       throws TableNotFoundException {
-    if (!tableNodeExists(tableId))
+    if (!tableNodeExists(tableId)) {
       throw new TableNotFoundException(tableId.canonical(), tableName, "Table no longer exists");
+    }
     return tableId;
   }
 
   // use cases overlap with requireTableExists, but this throws a runtime exception
   public TableId requireNotDeleted(TableId tableId) {
-    if (!tableNodeExists(tableId))
+    if (!tableNodeExists(tableId)) {
       throw new TableDeletedException(tableId.canonical());
+    }
     return tableId;
   }
 
   public TableId requireNotOffline(TableId tableId, String tableName) {
-    if (getTableState(tableId) == TableState.OFFLINE)
+    if (getTableState(tableId) == TableState.OFFLINE) {
       throw new TableOfflineException(tableId, tableName);
+    }
     return tableId;
   }
 
@@ -831,8 +832,9 @@ public class ClientContext implements AccumuloClient {
   @Override
   public synchronized SecurityOperations securityOperations() {
     ensureOpen();
-    if (secops == null)
+    if (secops == null) {
       secops = new SecurityOperationsImpl(this);
+    }
 
     return secops;
   }
@@ -840,8 +842,9 @@ public class ClientContext implements AccumuloClient {
   @Override
   public synchronized InstanceOperations instanceOperations() {
     ensureOpen();
-    if (instanceops == null)
+    if (instanceops == null) {
       instanceops = new InstanceOperationsImpl(this);
+    }
 
     return instanceops;
   }
