@@ -18,6 +18,8 @@
  */
 package org.apache.accumulo.core.clientImpl;
 
+import static java.util.concurrent.TimeUnit.MILLISECONDS;
+import static java.util.concurrent.TimeUnit.MINUTES;
 import static java.util.concurrent.TimeUnit.SECONDS;
 
 import java.io.IOException;
@@ -77,6 +79,7 @@ import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.ByteBufferUtil;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.OpTimer;
+import org.apache.accumulo.core.util.Retry;
 import org.apache.thrift.TApplicationException;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransportException;
@@ -107,7 +110,7 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
 
   private Map<String,TimeoutTracker> timeoutTrackers;
   private Set<String> timedoutServers;
-  private final long timeout;
+  private final long retryTimeout;
 
   private TabletLocator locator;
 
@@ -119,7 +122,7 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
 
   public TabletServerBatchReaderIterator(ClientContext context, TableId tableId, String tableName,
       Authorizations authorizations, ArrayList<Range> ranges, int numThreads,
-      ExecutorService queryThreadPool, ScannerOptions scannerOptions, long timeout) {
+      ExecutorService queryThreadPool, ScannerOptions scannerOptions, long retryTimeout) {
 
     this.context = context;
     this.tableId = tableId;
@@ -130,11 +133,11 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
     this.options = new ScannerOptions(scannerOptions);
     resultsQueue = new ArrayBlockingQueue<>(numThreads);
 
-    this.locator = new TimeoutTabletLocator(timeout, context, tableId);
+    this.locator = new TimeoutTabletLocator(retryTimeout, context, tableId);
 
     timeoutTrackers = Collections.synchronizedMap(new HashMap<>());
     timedoutServers = Collections.synchronizedSet(new HashSet<>());
-    this.timeout = timeout;
+    this.retryTimeout = retryTimeout;
 
     if (!options.fetchedColumns.isEmpty()) {
       ArrayList<Range> ranges2 = new ArrayList<>(ranges.size());
@@ -149,10 +152,11 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
       try {
         resultsQueue.put(entries);
       } catch (InterruptedException e) {
-        if (TabletServerBatchReaderIterator.this.queryThreadPool.isShutdown())
+        if (TabletServerBatchReaderIterator.this.queryThreadPool.isShutdown()) {
           log.debug("Failed to add Batch Scan result", e);
-        else
+        } else {
           log.warn("Failed to add Batch Scan result", e);
+        }
         fatalException = e;
         throw new RuntimeException(e);
 
@@ -171,23 +175,28 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
   @Override
   public boolean hasNext() {
     synchronized (nextLock) {
-      if (batch == LAST_BATCH)
+      if (batch == LAST_BATCH) {
         return false;
+      }
 
-      if (batch != null && batchIterator.hasNext())
+      if (batch != null && batchIterator.hasNext()) {
         return true;
+      }
 
       // don't have one cached, try to cache one and return success
       try {
         batch = null;
-        while (batch == null && fatalException == null && !queryThreadPool.isShutdown())
+        while (batch == null && fatalException == null && !queryThreadPool.isShutdown()) {
           batch = resultsQueue.poll(1, SECONDS);
+        }
 
-        if (fatalException != null)
-          if (fatalException instanceof RuntimeException)
+        if (fatalException != null) {
+          if (fatalException instanceof RuntimeException) {
             throw (RuntimeException) fatalException;
-          else
+          } else {
             throw new RuntimeException(fatalException);
+          }
+        }
 
         if (queryThreadPool.isShutdown()) {
           String shortMsg =
@@ -211,10 +220,11 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
   public Entry<Key,Value> next() {
     // if there's one waiting, or hasNext() can get one, return it
     synchronized (nextLock) {
-      if (hasNext())
+      if (hasNext()) {
         return batchIterator.next();
-      else
+      } else {
         throw new NoSuchElementException();
+      }
     }
   }
 
@@ -241,6 +251,10 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
 
     int lastFailureSize = Integer.MAX_VALUE;
 
+    Retry retry = Retry.builder().infiniteRetries().retryAfter(100, MILLISECONDS)
+        .incrementBy(100, MILLISECONDS).maxWait(10, SECONDS).backOffFactor(1.07)
+        .logInterval(1, MINUTES).createFactory().createRetry();
+
     while (true) {
 
       binnedRanges.clear();
@@ -262,15 +276,17 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
         }
         lastFailureSize = failures.size();
 
-        if (log.isTraceEnabled())
+        if (log.isTraceEnabled()) {
           log.trace("Failed to bin {} ranges, tablet locations were null, retrying in 100ms",
               failures.size());
+        }
 
         try {
-          Thread.sleep(100);
+          retry.waitForNextAttempt(log, "binRanges retry failures");
         } catch (InterruptedException e) {
           throw new RuntimeException(e);
         }
+
       }
 
     }
@@ -285,8 +301,9 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
         Range tabletRange = tabletRanges.getKey().toDataRange();
         List<Range> clippedRanges = new ArrayList<>();
         tabletMap.put(tabletRanges.getKey(), clippedRanges);
-        for (Range range : tabletRanges.getValue())
+        for (Range range : tabletRanges.getValue()) {
           clippedRanges.add(tabletRange.clip(range));
+        }
       }
     }
 
@@ -297,8 +314,9 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
   private void processFailures(Map<KeyExtent,List<Range>> failures, ResultReceiver receiver,
       List<Column> columns, Duration scanServerSelectorDelay)
       throws AccumuloException, AccumuloSecurityException, TableNotFoundException {
-    if (log.isTraceEnabled())
+    if (log.isTraceEnabled()) {
       log.trace("Failed to execute multiscans against {} tablets, retrying...", failures.size());
+    }
 
     try {
       if (scanServerSelectorDelay != null) {
@@ -319,8 +337,9 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
     Map<String,Map<KeyExtent,List<Range>>> binnedRanges = new HashMap<>();
     List<Range> allRanges = new ArrayList<>();
 
-    for (List<Range> ranges : failures.values())
+    for (List<Range> ranges : failures.values()) {
       allRanges.addAll(ranges);
+    }
 
     // since the first call to binRanges clipped the ranges to within a tablet, we should not get
     // only
@@ -376,7 +395,7 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
       try {
         TimeoutTracker timeoutTracker = timeoutTrackers.get(tsLocation);
         if (timeoutTracker == null) {
-          timeoutTracker = new TimeoutTracker(tsLocation, timedoutServers, timeout);
+          timeoutTracker = new TimeoutTracker(tsLocation, timedoutServers, retryTimeout);
           timeoutTrackers.put(tsLocation, timeoutTracker);
         }
         doLookup(context, tsLocation, tabletsRanges, tsFailures, unscanned, receiver, columns,
@@ -410,17 +429,19 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
         log.debug("AccumuloSecurityException thrown", e);
 
         context.clearTableListCache();
-        if (context.tableNodeExists(tableId))
+        if (context.tableNodeExists(tableId)) {
           fatalException = e;
-        else
+        } else {
           fatalException = new TableDeletedException(tableId.canonical());
+        }
       } catch (SampleNotPresentException e) {
         fatalException = e;
       } catch (Exception t) {
-        if (queryThreadPool.isShutdown())
+        if (queryThreadPool.isShutdown()) {
           log.debug("Caught exception, but queryThreadPool is shutdown", t);
-        else
+        } else {
           log.warn("Caught exception, but queryThreadPool is not shutdown", t);
+        }
         fatalException = t;
       } catch (Throwable t) {
         fatalException = t;
@@ -774,11 +795,12 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
     try {
       final HostAndPort parsedServer = HostAndPort.fromString(server);
       final TabletScanClientService.Client client;
-      if (timeoutTracker.getTimeOut() < context.getClientTimeoutInMillis())
+      if (timeoutTracker.getTimeOut() < context.getClientTimeoutInMillis()) {
         client = ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedServer, context,
             timeoutTracker.getTimeOut());
-      else
+      } else {
         client = ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedServer, context);
+      }
 
       try {
 
@@ -812,9 +834,10 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
             options.serverSideIteratorList, options.serverSideIteratorOptions,
             ByteBufferUtil.toByteBuffers(authorizations.getAuthorizations()), waitForWrites,
             SamplerConfigurationImpl.toThrift(options.getSamplerConfiguration()),
-            options.batchTimeOut, options.classLoaderContext, execHints, busyTimeout);
-        if (waitForWrites)
+            options.batchTimeout, options.classLoaderContext, execHints, busyTimeout);
+        if (waitForWrites) {
           ThriftScanner.serversWaitedForWrites.get(ttype).add(server.toString());
+        }
 
         MultiScanResult scanResult = imsr.result;
 
@@ -831,11 +854,13 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
           entries.add(new SimpleImmutableEntry<>(new Key(kv.key), new Value(kv.value)));
         }
 
-        if (!entries.isEmpty())
+        if (!entries.isEmpty()) {
           receiver.receive(entries);
+        }
 
-        if (!entries.isEmpty() || !scanResult.fullScans.isEmpty())
+        if (!entries.isEmpty() || !scanResult.fullScans.isEmpty()) {
           timeoutTracker.madeProgress();
+        }
 
         trackScanning(failures, unscanned, scanResult);
 
@@ -866,11 +891,13 @@ public class TabletServerBatchReaderIterator implements Iterator<Entry<Key,Value
             entries.add(new SimpleImmutableEntry<>(new Key(kv.key), new Value(kv.value)));
           }
 
-          if (!entries.isEmpty())
+          if (!entries.isEmpty()) {
             receiver.receive(entries);
+          }
 
-          if (!entries.isEmpty() || !scanResult.fullScans.isEmpty())
+          if (!entries.isEmpty() || !scanResult.fullScans.isEmpty()) {
             timeoutTracker.madeProgress();
+          }
 
           trackScanning(failures, unscanned, scanResult);
         }
