@@ -21,6 +21,7 @@ package org.apache.accumulo.core.file.rfile;
 import java.io.IOException;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.EnumSet;
 
 import org.apache.accumulo.core.client.sample.Sampler;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
@@ -36,22 +37,28 @@ import org.apache.accumulo.core.file.rfile.bcfile.BCFile;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.sample.impl.SamplerFactory;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.fs.CreateFlag;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.fs.permission.FsPermission;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
 
 public class RFileOperations extends FileOperations {
 
+  private static final Logger LOG = LoggerFactory.getLogger(RFileOperations.class);
+
   private static final Collection<ByteSequence> EMPTY_CF_SET = Collections.emptySet();
 
   private static RFile.Reader getReader(FileOptions options) throws IOException {
-    CachableBuilder cb =
-        new CachableBuilder().fsPath(options.getFileSystem(), new Path(options.getFilename()))
-            .conf(options.getConfiguration()).fileLen(options.getFileLenCache())
-            .cacheProvider(options.cacheProvider).readLimiter(options.getRateLimiter())
-            .cryptoService(options.getCryptoService());
+    CachableBuilder cb = new CachableBuilder()
+        .fsPath(options.getFileSystem(), new Path(options.getFilename()), options.dropCacheBehind)
+        .conf(options.getConfiguration()).fileLen(options.getFileLenCache())
+        .cacheProvider(options.cacheProvider).readLimiter(options.getRateLimiter())
+        .cryptoService(options.getCryptoService());
     return new RFile.Reader(cb);
   }
 
@@ -121,14 +128,31 @@ public class RFileOperations extends FileOperations {
       long hblock = conf.getLong("dfs.block.size", 1 << 26);
       long tblock = acuconf.getAsBytes(Property.TABLE_FILE_BLOCK_SIZE);
       long block = hblock;
-      if (tblock > 0)
+      if (tblock > 0) {
         block = tblock;
+      }
       int bufferSize = conf.getInt("io.file.buffer.size", 4096);
 
       String file = options.getFilename();
       FileSystem fs = options.getFileSystem();
 
-      outputStream = fs.create(new Path(file), false, bufferSize, (short) rep, block);
+      if (options.dropCacheBehind) {
+        EnumSet<CreateFlag> set = EnumSet.of(CreateFlag.SYNC_BLOCK, CreateFlag.CREATE);
+        outputStream = fs.create(new Path(file), FsPermission.getDefault(), set, bufferSize,
+            (short) rep, block, null);
+        try {
+          // Tell the DataNode that the file does not need to be cached in the OS page cache
+          outputStream.setDropBehind(Boolean.TRUE);
+          LOG.trace("Called setDropBehind(TRUE) for stream writing file {}", options.filename);
+        } catch (UnsupportedOperationException e) {
+          LOG.debug("setDropBehind not enabled for file: {}", options.filename);
+        } catch (IOException e) {
+          LOG.debug("IOException setting drop behind for file: {}, msg: {}", options.filename,
+              e.getMessage());
+        }
+      } else {
+        outputStream = fs.create(new Path(file), false, bufferSize, (short) rep, block);
+      }
     }
 
     BCFile.Writer _cbw = new BCFile.Writer(outputStream, options.getRateLimiter(), compression,
