@@ -202,8 +202,7 @@ public class MetadataSchema {
       }
 
       /**
-       * @throws IllegalArgumentException
-       *           when {@link #isValidDirCol(String)} returns false.
+       * @throws IllegalArgumentException when {@link #isValidDirCol(String)} returns false.
        */
       public static void validateDirCol(String dirName) {
         Preconditions.checkArgument(isValidDirCol(dirName), "Invalid dir name %s", dirName);
@@ -402,6 +401,23 @@ public class MetadataSchema {
 
   }
 
+  /**
+   * Holds error message processing flags
+   */
+  public static class ProblemSection {
+    private static final Section section =
+        new Section(RESERVED_PREFIX + "err_", true, RESERVED_PREFIX + "err`", false);
+
+    public static Range getRange() {
+      return section.getRange();
+    }
+
+    public static String getRowPrefix() {
+      return section.getRowPrefix();
+    }
+
+  }
+
   /**
    * Holds references to files that need replication
    *
@@ -428,8 +444,7 @@ public class MetadataSchema {
     /**
      * Extract the table ID from the colfam
      *
-     * @param k
-     *          Key to extract from
+     * @param k Key to extract from
      */
     public static TableId getTableId(Key k) {
       requireNonNull(k);
@@ -439,10 +454,8 @@ public class MetadataSchema {
     /**
      * Extract the file name from the row suffix into the given {@link Text}
      *
-     * @param k
-     *          Key to extract from
-     * @param buff
-     *          Text to place file name into
+     * @param k Key to extract from
+     * @param buff Text to place file name into
      */
     public static void getFile(Key k, Text buff) {
       requireNonNull(k);
