@@ -113,10 +113,8 @@ public class ThreadPools {
   /**
    * Checks to see if a ScheduledFuture has exited successfully or thrown an error
    *
-   * @param future
-   *          scheduled future to check
-   * @param taskQueue
-   *          the running task queue from which the future came
+   * @param future scheduled future to check
+   * @param taskQueue the running task queue from which the future came
    * @return true if the future should be removed
    */
   private static boolean checkTaskFailed(ScheduledFuture<?> future,
@@ -192,12 +190,9 @@ public class ThreadPools {
   /**
    * Resize ThreadPoolExecutor based on current value of maxThreads
    *
-   * @param pool
-   *          the ThreadPoolExecutor to modify
-   * @param maxThreads
-   *          supplier of maxThreads value
-   * @param poolName
-   *          name of the thread pool
+   * @param pool the ThreadPoolExecutor to modify
+   * @param maxThreads supplier of maxThreads value
+   * @param poolName name of the thread pool
    */
   public static void resizePool(final ThreadPoolExecutor pool, final IntSupplier maxThreads,
       String poolName) {
@@ -222,12 +217,9 @@ public class ThreadPools {
   /**
    * Resize ThreadPoolExecutor based on current value of Property p
    *
-   * @param pool
-   *          the ThreadPoolExecutor to modify
-   * @param conf
-   *          the AccumuloConfiguration
-   * @param p
-   *          the property to base the size from
+   * @param pool the ThreadPoolExecutor to modify
+   * @param conf the AccumuloConfiguration
+   * @param p the property to base the size from
    */
   public static void resizePool(final ThreadPoolExecutor pool, final AccumuloConfiguration conf,
       final Property p) {
@@ -243,20 +235,16 @@ public class ThreadPools {
   /**
    * Create a thread pool based on a thread pool related property
    *
-   * @param conf
-   *          accumulo configuration
-   * @param p
-   *          thread pool related property
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param conf accumulo configuration
+   * @param p thread pool related property
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ExecutorService impl
-   * @throws RuntimeException
-   *           if property is not handled
+   * @throws RuntimeException if property is not handled
    */
   @SuppressWarnings("deprecation")
   public ThreadPoolExecutor createExecutorService(final AccumuloConfiguration conf,
@@ -318,17 +306,14 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param numThreads
-   *          number of threads
-   * @param name
-   *          thread pool name
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param numThreads number of threads
+   * @param name thread pool name
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createFixedThreadPool(int numThreads, final String name,
@@ -340,19 +325,15 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param numThreads
-   *          number of threads
-   * @param name
-   *          thread pool name
-   * @param queue
-   *          queue to use for tasks
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param numThreads number of threads
+   * @param name thread pool name
+   * @param queue queue to use for tasks
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createFixedThreadPool(int numThreads, final String name,
@@ -364,21 +345,16 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param numThreads
-   *          number of threads
-   * @param timeOut
-   *          core thread time out
-   * @param units
-   *          core thread time out units
-   * @param name
-   *          thread pool name
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param numThreads number of threads
+   * @param timeOut core thread time out
+   * @param units core thread time out units
+   * @param name thread pool name
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createFixedThreadPool(int numThreads, long timeOut, TimeUnit units,
@@ -389,23 +365,17 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param coreThreads
-   *          number of threads
-   * @param maxThreads
-   *          max number of threads
-   * @param timeOut
-   *          core thread time out
-   * @param units
-   *          core thread time out units
-   * @param name
-   *          thread pool name
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param coreThreads number of threads
+   * @param maxThreads max number of threads
+   * @param timeOut core thread time out
+   * @param units core thread time out units
+   * @param name thread pool name
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createThreadPool(int coreThreads, int maxThreads, long timeOut,
@@ -417,25 +387,18 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param coreThreads
-   *          number of threads
-   * @param maxThreads
-   *          max number of threads
-   * @param timeOut
-   *          core thread time out
-   * @param units
-   *          core thread time out units
-   * @param name
-   *          thread pool name
-   * @param queue
-   *          queue to use for tasks
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param coreThreads number of threads
+   * @param maxThreads max number of threads
+   * @param timeOut core thread time out
+   * @param units core thread time out units
+   * @param name thread pool name
+   * @param queue queue to use for tasks
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createThreadPool(int coreThreads, int maxThreads, long timeOut,
@@ -448,33 +411,25 @@ public class ThreadPools {
   /**
    * Create a named thread pool
    *
-   * @param coreThreads
-   *          number of threads
-   * @param maxThreads
-   *          max number of threads
-   * @param timeOut
-   *          core thread time out
-   * @param units
-   *          core thread time out units
-   * @param name
-   *          thread pool name
-   * @param queue
-   *          queue to use for tasks
-   * @param priority
-   *          thread priority
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param coreThreads number of threads
+   * @param maxThreads max number of threads
+   * @param timeOut core thread time out
+   * @param units core thread time out units
+   * @param name thread pool name
+   * @param queue queue to use for tasks
+   * @param priority thread priority
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ThreadPoolExecutor
    */
   public ThreadPoolExecutor createThreadPool(int coreThreads, int maxThreads, long timeOut,
       TimeUnit units, final String name, BlockingQueue<Runnable> queue, OptionalInt priority,
       boolean emitThreadPoolMetrics) {
-    LOG.debug(
+    LOG.trace(
         "Creating ThreadPoolExecutor for {} with {} core threads and {} max threads {} {} timeout",
         name, coreThreads, maxThreads, timeOut, units);
     var result = new ThreadPoolExecutor(coreThreads, maxThreads, timeOut, units, queue,
@@ -529,22 +484,19 @@ public class ThreadPools {
   /**
    * Create a named ScheduledThreadPool
    *
-   * @param numThreads
-   *          number of threads
-   * @param name
-   *          thread pool name
-   * @param emitThreadPoolMetrics
-   *          When set to true will emit metrics and register the metrics in a static registry.
-   *          After the thread pool is deleted, there will still be metrics objects related to it in
-   *          the static registry. There is no way to clean these left over objects up therefore its
-   *          recommended that this option only be set true for long lived thread pools. Creating
-   *          lots of short lived thread pools and registering them can lead to out of memory errors
-   *          over long time periods.
+   * @param numThreads number of threads
+   * @param name thread pool name
+   * @param emitThreadPoolMetrics When set to true will emit metrics and register the metrics in a
+   *        static registry. After the thread pool is deleted, there will still be metrics objects
+   *        related to it in the static registry. There is no way to clean these left over objects
+   *        up therefore its recommended that this option only be set true for long lived thread
+   *        pools. Creating lots of short lived thread pools and registering them can lead to out of
+   *        memory errors over long time periods.
    * @return ScheduledThreadPoolExecutor
    */
   public ScheduledThreadPoolExecutor createScheduledExecutorService(int numThreads,
       final String name, boolean emitThreadPoolMetrics) {
-    LOG.debug("Creating ScheduledThreadPoolExecutor for {} with {} threads", name, numThreads);
+    LOG.trace("Creating ScheduledThreadPoolExecutor for {} with {} threads", name, numThreads);
     var result =
         new ScheduledThreadPoolExecutor(numThreads, new NamedThreadFactory(name, handler)) {
 
