@@ -28,6 +28,7 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.WithTestNames;
+import org.apache.accumulo.core.file.rfile.RFile;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
@@ -144,6 +145,12 @@ public class PropertyTypeTest extends WithTestNames {
     invalid("", "other");
   }
 
+  @Test
+  public void testTypeLAST_LOCATION_MODE() {
+    valid(null, "compaction", "assignment");
+    invalid("", "other");
+  }
+
   @Test
   public void testTypeFRACTION() {
     valid(null, "1", "0", "1.0", "25%", "2.5%", "10.2E-3", "10.2E-3%", ".3");
@@ -203,4 +210,10 @@ public class PropertyTypeTest extends WithTestNames {
     valid(null, "", "hdfs://hostname", "file:///path/", "hdfs://example.com:port/path");
   }
 
+  @Test
+  public void testTypeFILENAME_EXT() {
+    valid(RFile.EXTENSION, "rf");
+    invalid(null, "RF", "map", "", "MAP", "rF", "Rf", " rf ");
+  }
+
 }
