@@ -68,8 +68,9 @@ public class AccumuloRecordWriter extends RecordWriter<Text,Mutation> {
     this.simulate = OutputConfigurator.getSimulationMode(CLASS, conf);
     this.createTables = OutputConfigurator.canCreateTables(CLASS, conf);
 
-    if (simulate)
+    if (simulate) {
       log.info("Simulating output only. No writes to tables will occur");
+    }
 
     this.bws = new HashMap<>();
 
@@ -89,26 +90,30 @@ public class AccumuloRecordWriter extends RecordWriter<Text,Mutation> {
    */
   @Override
   public void write(Text table, Mutation mutation) throws IOException {
-    if (table == null || table.toString().isEmpty())
+    if (table == null || table.toString().isEmpty()) {
       table = this.defaultTableName;
+    }
 
-    if (!simulate && table == null)
+    if (!simulate && table == null) {
       throw new IOException("No table or default table specified. Try simulation mode next time");
+    }
 
     ++mutCount;
     valCount += mutation.size();
     printMutation(table, mutation);
 
-    if (simulate)
+    if (simulate) {
       return;
+    }
 
-    if (!bws.containsKey(table))
+    if (!bws.containsKey(table)) {
       try {
         addTable(table);
       } catch (AccumuloSecurityException | AccumuloException e) {
         log.error("Could not add table '" + table + "'", e);
         throw new IOException(e);
       }
+    }
 
     try {
       bws.get(table).addMutation(mutation);
@@ -147,8 +152,9 @@ public class AccumuloRecordWriter extends RecordWriter<Text,Mutation> {
       throw e;
     }
 
-    if (bw != null)
+    if (bw != null) {
       bws.put(tableName, bw);
+    }
   }
 
   private int printMutation(Text table, Mutation m) {
@@ -168,10 +174,11 @@ public class AccumuloRecordWriter extends RecordWriter<Text,Mutation> {
   private String hexDump(byte[] ba) {
     StringBuilder sb = new StringBuilder();
     for (byte b : ba) {
-      if ((b > 0x20) && (b < 0x7e))
+      if ((b > 0x20) && (b < 0x7e)) {
         sb.append((char) b);
-      else
+      } else {
         sb.append(String.format("x%02x", b));
+      }
     }
     return sb.toString();
   }
@@ -179,8 +186,9 @@ public class AccumuloRecordWriter extends RecordWriter<Text,Mutation> {
   @Override
   public void close(TaskAttemptContext attempt) throws IOException {
     log.debug("mutations written: " + mutCount + ", values written: " + valCount);
-    if (simulate)
+    if (simulate) {
       return;
+    }
 
     try {
       mtbw.close();
