@@ -107,9 +107,10 @@ public class ClientServiceHandler implements ClientService.Iface {
       // and check again
       context.clearTableListCache();
       namespaceId = Namespaces.lookupNamespaceId(context, namespaceName);
-      if (namespaceId == null)
+      if (namespaceId == null) {
         throw new ThriftTableOperationException(null, namespaceName, operation,
             TableOperationExceptionType.NAMESPACE_NOTFOUND, null);
+      }
     }
     return namespaceId;
   }
@@ -298,8 +299,9 @@ public class ClientServiceHandler implements ClientService.Iface {
     Map<String,String> result = new HashMap<>();
     for (Entry<String,String> entry : conf) {
       String key = entry.getKey();
-      if (!Property.isSensitive(key))
+      if (!Property.isSensitive(key)) {
         result.put(key, entry.getValue());
+      }
     }
     return result;
   }
@@ -370,7 +372,8 @@ public class ClientServiceHandler implements ClientService.Iface {
       throws ThriftSecurityException {
     checkSystemPermission(credentials);
     return Optional.of(context.getPropStore().get(SystemPropKey.of(context)))
-        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap()))
+        .orElseThrow();
   }
 
   @Override
@@ -397,7 +400,8 @@ public class ClientServiceHandler implements ClientService.Iface {
     final TableId tableId = checkTableId(context, tableName, null);
     checkTablePermission(credentials, tableId, TablePermission.ALTER_TABLE);
     return Optional.of(context.getPropStore().get(TablePropKey.of(context, tableId)))
-        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap()))
+        .orElseThrow();
   }
 
   @Override
@@ -405,9 +409,10 @@ public class ClientServiceHandler implements ClientService.Iface {
       final String tableId, final List<String> files, final String errorDir, final boolean setTime)
       throws ThriftSecurityException, ThriftTableOperationException, TException {
     try {
-      if (!security.canPerformSystemActions(credentials))
+      if (!security.canPerformSystemActions(credentials)) {
         throw new AccumuloSecurityException(credentials.getPrincipal(),
             SecurityErrorCode.PERMISSION_DENIED);
+      }
       bulkImportStatus.updateBulkImportStatus(files, BulkImportState.INITIAL);
       log.debug("Got request to bulk import files to table({}): {}", tableId, files);
 
@@ -506,9 +511,10 @@ public class ClientServiceHandler implements ClientService.Iface {
         TableId tableId = checkTableId(context, table, null);
         tableIds.add(tableId);
         NamespaceId namespaceId = context.getNamespaceId(tableId);
-        if (!security.canScan(credentials, tableId, namespaceId))
+        if (!security.canScan(credentials, tableId, namespaceId)) {
           throw new ThriftSecurityException(credentials.getPrincipal(),
               SecurityErrorCode.PERMISSION_DENIED);
+        }
       }
 
       // use the same set of tableIds that were validated above to avoid race conditions
@@ -566,7 +572,8 @@ public class ClientServiceHandler implements ClientService.Iface {
       namespaceId = Namespaces.getNamespaceId(context, ns);
       checkNamespacePermission(credentials, namespaceId, NamespacePermission.ALTER_NAMESPACE);
       return Optional.of(context.getPropStore().get(NamespacePropKey.of(context, namespaceId)))
-          .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+          .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap()))
+          .orElseThrow();
     } catch (NamespaceNotFoundException e) {
       String why = "Could not find namespace while getting configuration.";
       throw new ThriftTableOperationException(null, ns, null,
