@@ -47,7 +47,6 @@ import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.BatchWriterConfig;
-import org.apache.accumulo.core.client.IsolatedScanner;
 import org.apache.accumulo.core.client.MutationsRejectedException;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableNotFoundException;
@@ -62,7 +61,6 @@ import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.fate.FateTxId;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
 import org.apache.accumulo.core.gc.ReferenceFile;
 import org.apache.accumulo.core.metadata.MetadataTable;
@@ -73,9 +71,7 @@ import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.Ample.TabletMutator;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.BlipSection;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.BulkFileColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ChoppedColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ClonedColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.CurrentLocationColumnFamily;
@@ -91,7 +87,6 @@ import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.tabletserver.log.LogEntry;
 import org.apache.accumulo.core.tabletserver.thrift.ConstraintViolationException;
-import org.apache.accumulo.core.util.ColumnFQ;
 import org.apache.accumulo.core.util.FastFormat;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.server.ServerContext;
@@ -139,10 +134,6 @@ public class MetadataTableUtil {
         new Value(zooLock.getLockID().serialize(context.getZooKeeperRoot() + "/")));
   }
 
-  private static void update(ServerContext context, Mutation m, KeyExtent extent) {
-    update(context, null, m, extent);
-  }
-
   public static void update(ServerContext context, ServiceLock zooLock, Mutation m,
       KeyExtent extent) {
     Writer t = extent.isMeta() ? getRootTable(context) : getMetadataTable(context);
@@ -151,8 +142,9 @@ public class MetadataTableUtil {
 
   public static void update(ServerContext context, Writer t, ServiceLock zooLock, Mutation m,
       KeyExtent extent) {
-    if (zooLock != null)
+    if (zooLock != null) {
       putLockID(context, zooLock, m);
+    }
     while (true) {
       try {
         t.update(m);
@@ -205,14 +197,6 @@ public class MetadataTableUtil {
     return newFiles;
   }
 
-  public static void updateTabletDir(KeyExtent extent, String newDir, ServerContext context,
-      ServiceLock zooLock) {
-    TabletMutator tablet = context.getAmple().mutateTablet(extent);
-    tablet.putDirName(newDir);
-    tablet.putZooLock(zooLock);
-    tablet.mutate();
-  }
-
   public static void addTablet(KeyExtent extent, String path, ServerContext context,
       TimeType timeType, ServiceLock zooLock) {
     TabletMutator tablet = context.getAmple().mutateTablet(extent);
@@ -274,7 +258,7 @@ public class MetadataTableUtil {
     ChoppedColumnFamily.CHOPPED_COLUMN.putDelete(m);
 
     for (Entry<StoredTabletFile,DataFileValue> entry : datafileSizes.entrySet()) {
-      m.put(DataFileColumnFamily.NAME, entry.getKey().getMetaInsertText(),
+      m.put(DataFileColumnFamily.NAME, entry.getKey().getMetaUpdateDeleteText(),
           new Value(entry.getValue().encode()));
     }
 
@@ -393,21 +377,24 @@ public class MetadataTableUtil {
 
         if (m == null) {
           m = new Mutation(key.getRow());
-          if (lock != null)
+          if (lock != null) {
             putLockID(context, lock, m);
+          }
         }
 
         if (key.getRow().compareTo(m.getRow(), 0, m.getRow().length) != 0) {
           bw.addMutation(m);
           m = new Mutation(key.getRow());
-          if (lock != null)
+          if (lock != null) {
             putLockID(context, lock, m);
+          }
         }
         m.putDelete(key.getColumnFamily(), key.getColumnQualifier());
       }
 
-      if (m != null)
+      if (m != null) {
         bw.addMutation(m);
+      }
     }
   }
 
@@ -446,8 +433,9 @@ public class MetadataTableUtil {
     for (Entry<Key,Value> entry : tablet.entrySet()) {
       if (entry.getKey().getColumnFamily().equals(DataFileColumnFamily.NAME)) {
         String cf = entry.getKey().getColumnQualifier().toString();
-        if (!cf.startsWith("../") && !cf.contains(":"))
+        if (!cf.startsWith("../") && !cf.contains(":")) {
           cf = "../" + srcTableId + entry.getKey().getColumnQualifier();
+        }
         m.put(entry.getKey().getColumnFamily(), new Text(cf), entry.getValue());
       } else if (entry.getKey().getColumnFamily().equals(CurrentLocationColumnFamily.NAME)) {
         m.put(LastLocationColumnFamily.NAME, entry.getKey().getColumnQualifier(), entry.getValue());
@@ -489,11 +477,13 @@ public class MetadataTableUtil {
 
     Iterator<TabletMetadata> ti = createCloneScanner(testTableName, srcTableId, client).iterator();
 
-    if (!ti.hasNext())
+    if (!ti.hasNext()) {
       throw new RuntimeException(" table deleted during clone?  srcTableId = " + srcTableId);
+    }
 
-    while (ti.hasNext())
+    while (ti.hasNext()) {
       bw.addMutation(createCloneMutation(srcTableId, tableId, ti.next().getKeyValues()));
+    }
 
     bw.flush();
   }
@@ -513,9 +503,10 @@ public class MetadataTableUtil {
     Iterator<TabletMetadata> cloneIter =
         createCloneScanner(testTableName, tableId, client).iterator();
 
-    if (!cloneIter.hasNext() || !srcIter.hasNext())
+    if (!cloneIter.hasNext() || !srcIter.hasNext()) {
       throw new RuntimeException(
           " table deleted during clone?  srcTableId = " + srcTableId + " tableId=" + tableId);
+    }
 
     int rewrites = 0;
 
@@ -526,8 +517,9 @@ public class MetadataTableUtil {
 
       boolean cloneSuccessful = cloneTablet.getCloned() != null;
 
-      if (!cloneSuccessful)
+      if (!cloneSuccessful) {
         cloneFiles.addAll(cloneTablet.getFiles());
+      }
 
       List<TabletMetadata> srcTablets = new ArrayList<>();
       TabletMetadata srcTablet = srcIter.next();
@@ -535,29 +527,34 @@ public class MetadataTableUtil {
 
       Text srcEndRow = srcTablet.getEndRow();
       int cmp = compareEndRows(cloneEndRow, srcEndRow);
-      if (cmp < 0)
+      if (cmp < 0) {
         throw new TabletDeletedException(
             "Tablets deleted from src during clone : " + cloneEndRow + " " + srcEndRow);
+      }
 
       HashSet<TabletFile> srcFiles = new HashSet<>();
-      if (!cloneSuccessful)
+      if (!cloneSuccessful) {
         srcFiles.addAll(srcTablet.getFiles());
+      }
 
       while (cmp > 0) {
         srcTablet = srcIter.next();
         srcTablets.add(srcTablet);
         srcEndRow = srcTablet.getEndRow();
         cmp = compareEndRows(cloneEndRow, srcEndRow);
-        if (cmp < 0)
+        if (cmp < 0) {
           throw new TabletDeletedException(
               "Tablets deleted from src during clone : " + cloneEndRow + " " + srcEndRow);
+        }
 
-        if (!cloneSuccessful)
+        if (!cloneSuccessful) {
           srcFiles.addAll(srcTablet.getFiles());
+        }
       }
 
-      if (cloneSuccessful)
+      if (cloneSuccessful) {
         continue;
+      }
 
       if (srcFiles.containsAll(cloneFiles)) {
         // write out marker that this tablet was successfully cloned
@@ -575,8 +572,9 @@ public class MetadataTableUtil {
 
         bw.addMutation(m);
 
-        for (TabletMetadata st : srcTablets)
+        for (TabletMetadata st : srcTablets) {
           bw.addMutation(createCloneMutation(srcTableId, tableId, st.getKeyValues()));
+        }
 
         rewrites++;
       }
@@ -602,8 +600,9 @@ public class MetadataTableUtil {
           while (true) {
             int rewrites = checkClone(null, srcTableId, tableId, context, bw);
 
-            if (rewrites == 0)
+            if (rewrites == 0) {
               break;
+            }
           }
 
           bw.flush();
@@ -650,63 +649,4 @@ public class MetadataTableUtil {
     tablet.mutate();
   }
 
-  public static void removeBulkLoadEntries(AccumuloClient client, TableId tableId, long tid)
-      throws Exception {
-    try (
-        Scanner mscanner =
-            new IsolatedScanner(client.createScanner(MetadataTable.NAME, Authorizations.EMPTY));
-        BatchWriter bw = client.createBatchWriter(MetadataTable.NAME)) {
-      mscanner.setRange(new KeyExtent(tableId, null, null).toMetaRange());
-      mscanner.fetchColumnFamily(BulkFileColumnFamily.NAME);
-
-      for (Entry<Key,Value> entry : mscanner) {
-        log.trace("Looking at entry {} with tid {}", entry, tid);
-        long entryTid = BulkFileColumnFamily.getBulkLoadTid(entry.getValue());
-        if (tid == entryTid) {
-          log.trace("deleting entry {}", entry);
-          Key key = entry.getKey();
-          Mutation m = new Mutation(key.getRow());
-          m.putDelete(key.getColumnFamily(), key.getColumnQualifier());
-          bw.addMutation(m);
-        }
-      }
-    }
-  }
-
-  public static void addBulkLoadInProgressFlag(ServerContext context, String path, long fateTxid) {
-
-    Mutation m = new Mutation(BlipSection.getRowPrefix() + path);
-    m.put(EMPTY_TEXT, EMPTY_TEXT, new Value(FateTxId.formatTid(fateTxid)));
-
-    // new KeyExtent is only added to force update to write to the metadata table, not the root
-    // table
-    // because bulk loads aren't supported to the metadata table
-    update(context, m, new KeyExtent(TableId.of("anythingNotMetadata"), null, null));
-  }
-
-  public static void removeBulkLoadInProgressFlag(ServerContext context, String path) {
-
-    Mutation m = new Mutation(BlipSection.getRowPrefix() + path);
-    m.putDelete(EMPTY_TEXT, EMPTY_TEXT);
-
-    // new KeyExtent is only added to force update to write to the metadata table, not the root
-    // table because bulk loads aren't supported to the metadata table
-    update(context, m, new KeyExtent(TableId.of("anythingNotMetadata"), null, null));
-  }
-
-  public static SortedMap<Text,SortedMap<ColumnFQ,Value>>
-      getTabletEntries(SortedMap<Key,Value> tabletKeyValues, List<ColumnFQ> columns) {
-    TreeMap<Text,SortedMap<ColumnFQ,Value>> tabletEntries = new TreeMap<>();
-
-    HashSet<ColumnFQ> colSet = columns == null ? null : new HashSet<>(columns);
-
-    tabletKeyValues.forEach((key, val) -> {
-      ColumnFQ currentKey = new ColumnFQ(key);
-      if (columns == null || colSet.contains(currentKey)) {
-        tabletEntries.computeIfAbsent(key.getRow(), k -> new TreeMap<>()).put(currentKey, val);
-      }
-    });
-
-    return tabletEntries;
-  }
 }
