@@ -1,37 +1,42 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.constraints;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.util.List;
 
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.BulkFileColumnFamily;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.CurrentLocationColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ServerColumnFamily;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.TabletColumnFamily;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.zookeeper.TransactionWatcher.Arbitrator;
 import org.apache.hadoop.io.Text;
 import org.easymock.EasyMock;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class MetadataConstraintsTest {
 
@@ -67,7 +72,7 @@ public class MetadataConstraintsTest {
   @Test
   public void testCheck() {
     Mutation m = new Mutation(new Text("0;foo"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1foo".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1foo"));
 
     MetadataConstraints mc = new MetadataConstraints();
 
@@ -78,7 +83,7 @@ public class MetadataConstraintsTest {
     assertEquals(Short.valueOf((short) 3), violations.get(0));
 
     m = new Mutation(new Text("0:foo"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1poo".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1poo"));
 
     violations = mc.check(createEnv(), m);
 
@@ -87,7 +92,7 @@ public class MetadataConstraintsTest {
     assertEquals(Short.valueOf((short) 4), violations.get(0));
 
     m = new Mutation(new Text("0;foo"));
-    m.put(new Text("bad_column_name"), new Text(""), new Value("e".getBytes()));
+    m.put("bad_column_name", "", "e");
 
     violations = mc.check(createEnv(), m);
 
@@ -96,7 +101,7 @@ public class MetadataConstraintsTest {
     assertEquals(Short.valueOf((short) 2), violations.get(0));
 
     m = new Mutation(new Text("!!<"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1poo".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("1poo"));
 
     violations = mc.check(createEnv(), m);
 
@@ -106,7 +111,7 @@ public class MetadataConstraintsTest {
     assertEquals(Short.valueOf((short) 5), violations.get(1));
 
     m = new Mutation(new Text("0;foo"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value(""));
 
     violations = mc.check(createEnv(), m);
 
@@ -115,21 +120,21 @@ public class MetadataConstraintsTest {
     assertEquals(Short.valueOf((short) 6), violations.get(0));
 
     m = new Mutation(new Text("0;foo"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar"));
 
     violations = mc.check(createEnv(), m);
 
     assertNull(violations);
 
     m = new Mutation(new Text("!0<"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar"));
 
     violations = mc.check(createEnv(), m);
 
     assertNull(violations);
 
     m = new Mutation(new Text("!1<"));
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar".getBytes()));
+    TabletColumnFamily.PREV_ROW_COLUMN.put(m, new Value("bar"));
 
     violations = mc.check(createEnv(), m);
 
@@ -147,8 +152,7 @@ public class MetadataConstraintsTest {
 
     // inactive txid
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("12345".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("12345"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
     violations = mc.check(createEnv(), m);
@@ -158,8 +162,7 @@ public class MetadataConstraintsTest {
 
     // txid that throws exception
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("9".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("9"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
     violations = mc.check(createEnv(), m);
@@ -169,8 +172,7 @@ public class MetadataConstraintsTest {
 
     // active txid w/ file
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
     violations = mc.check(createEnv(), m);
@@ -178,8 +180,7 @@ public class MetadataConstraintsTest {
 
     // active txid w/o file
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
     violations = mc.check(createEnv(), m);
     assertNotNull(violations);
     assertEquals(1, violations.size());
@@ -187,12 +188,10 @@ public class MetadataConstraintsTest {
 
     // two active txids w/ files
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile2"),
-        new Value("7".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile2"), new Value("7"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile2"),
         new DataFileValue(1, 1).encodeAsValue());
     violations = mc.check(createEnv(), m);
@@ -202,12 +201,10 @@ public class MetadataConstraintsTest {
 
     // two files w/ one active txid
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile2"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile2"), new Value("5"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile2"),
         new DataFileValue(1, 1).encodeAsValue());
     violations = mc.check(createEnv(), m);
@@ -215,12 +212,10 @@ public class MetadataConstraintsTest {
 
     // two loaded w/ one active txid and one file
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
     m.put(DataFileColumnFamily.NAME, new Text("/someFile"),
         new DataFileValue(1, 1).encodeAsValue());
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile2"),
-        new Value("5".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile2"), new Value("5"));
     violations = mc.check(createEnv(), m);
     assertNotNull(violations);
     assertEquals(1, violations.size());
@@ -228,41 +223,35 @@ public class MetadataConstraintsTest {
 
     // active txid, mutation that looks like split
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
-    TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.put(m, new Value("/t1".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
+    ServerColumnFamily.DIRECTORY_COLUMN.put(m, new Value("/t1"));
     violations = mc.check(createEnv(), m);
     assertNull(violations);
 
     // inactive txid, mutation that looks like split
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("12345".getBytes()));
-    TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.put(m, new Value("/t1".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("12345"));
+    ServerColumnFamily.DIRECTORY_COLUMN.put(m, new Value("/t1"));
     violations = mc.check(createEnv(), m);
     assertNull(violations);
 
     // active txid, mutation that looks like a load
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("5".getBytes()));
-    m.put(TabletsSection.CurrentLocationColumnFamily.NAME, new Text("789"),
-        new Value("127.0.0.1:9997".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("5"));
+    m.put(CurrentLocationColumnFamily.NAME, new Text("789"), new Value("127.0.0.1:9997"));
     violations = mc.check(createEnv(), m);
     assertNull(violations);
 
     // inactive txid, mutation that looks like a load
     m = new Mutation(new Text("0;foo"));
-    m.put(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"),
-        new Value("12345".getBytes()));
-    m.put(TabletsSection.CurrentLocationColumnFamily.NAME, new Text("789"),
-        new Value("127.0.0.1:9997".getBytes()));
+    m.put(BulkFileColumnFamily.NAME, new Text("/someFile"), new Value("12345"));
+    m.put(CurrentLocationColumnFamily.NAME, new Text("789"), new Value("127.0.0.1:9997"));
     violations = mc.check(createEnv(), m);
     assertNull(violations);
 
     // deleting a load flag
     m = new Mutation(new Text("0;foo"));
-    m.putDelete(TabletsSection.BulkFileColumnFamily.NAME, new Text("/someFile"));
+    m.putDelete(BulkFileColumnFamily.NAME, new Text("/someFile"));
     violations = mc.check(createEnv(), m);
     assertNull(violations);
 
