@@ -458,17 +458,20 @@ public class GCRun implements GarbageCollectionEnvironment {
    * throwing an exception.
    *
    * @return true if the file was moved to trash
-   * @throws IOException
-   *           if the volume manager encountered a problem
+   * @throws IOException if the volume manager encountered a problem
    */
   boolean moveToTrash(Path path) throws IOException {
     final VolumeManager fs = context.getVolumeManager();
     if (!isUsingTrash()) {
+      log.trace("Accumulo Trash is disabled. Skipped for {}", path);
       return false;
     }
     try {
-      return fs.moveToTrash(path);
+      boolean success = fs.moveToTrash(path);
+      log.trace("Accumulo Trash enabled, moving to trash succeeded?: {}", success);
+      return success;
     } catch (FileNotFoundException ex) {
+      log.error("Error moving {} to trash", path, ex);
       return false;
     }
   }
@@ -479,7 +482,9 @@ public class GCRun implements GarbageCollectionEnvironment {
    * @return true if trash is used
    */
   boolean isUsingTrash() {
-    return !config.getBoolean(Property.GC_TRASH_IGNORE);
+    @SuppressWarnings("removal")
+    Property p = Property.GC_TRASH_IGNORE;
+    return !config.getBoolean(p);
   }
 
   /**
@@ -516,8 +521,7 @@ public class GCRun implements GarbageCollectionEnvironment {
    * return the table id for the accumulo.root table.
    *
    * @return The table ids
-   * @throws InterruptedException
-   *           if interrupted when calling ZooKeeper
+   * @throws InterruptedException if interrupted when calling ZooKeeper
    */
   @Override
   public Set<TableId> getCandidateTableIDs() throws InterruptedException {
