@@ -74,6 +74,7 @@ import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.Fu
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ServerColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.TabletColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataTime;
+import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
 import org.apache.accumulo.core.util.threads.Threads.AccumuloDaemonThread;
@@ -93,6 +94,7 @@ import org.apache.accumulo.server.manager.state.DistributedStoreException;
 import org.apache.accumulo.server.manager.state.MergeInfo;
 import org.apache.accumulo.server.manager.state.MergeState;
 import org.apache.accumulo.server.manager.state.TabletStateStore;
+import org.apache.accumulo.server.manager.state.UnassignedTablet;
 import org.apache.accumulo.server.tablets.TabletTime;
 import org.apache.accumulo.server.util.MetadataTableUtil;
 import org.apache.hadoop.fs.Path;
@@ -145,18 +147,15 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
     private final List<Assignment> assigned = new ArrayList<>();
     private final List<TabletLocationState> assignedToDeadServers = new ArrayList<>();
     private final List<TabletLocationState> suspendedToGoneServers = new ArrayList<>();
-    private final Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
+    private final Map<KeyExtent,UnassignedTablet> unassigned = new HashMap<>();
     private final Map<TServerInstance,List<Path>> logsForDeadServers = new TreeMap<>();
-    // read only lists of tablet servers
-    private final SortedMap<TServerInstance,TabletServerStatus> currentTServers;
+    // read only list of tablet servers that are not shutting down
     private final SortedMap<TServerInstance,TabletServerStatus> destinations;
 
     public TabletLists(Manager m, SortedMap<TServerInstance,TabletServerStatus> curTServers) {
       var destinationsMod = new TreeMap<>(curTServers);
-      // Don't move tablets to servers that are shutting down
       destinationsMod.keySet().removeAll(m.serversToShutdown);
       this.destinations = Collections.unmodifiableSortedMap(destinationsMod);
-      this.currentTServers = Collections.unmodifiableSortedMap(curTServers);
     }
 
     public void reset() {
@@ -220,8 +219,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
           }
 
           // ignore entries for tables that do not exist in zookeeper
-          if (manager.getTableManager().getTableState(tls.extent.tableId()) == null)
+          if (manager.getTableManager().getTableState(tls.extent.tableId()) == null) {
             continue;
+          }
 
           // Don't overwhelm the tablet servers with work
           if (tLists.unassigned.size() + unloaded
@@ -239,11 +239,11 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
             return mStats != null ? mStats : new MergeStats(new MergeInfo());
           });
           TabletGoalState goal = manager.getGoalState(tls, mergeStats.getMergeInfo());
-          TServerInstance location = tls.getLocation();
+          Location location = tls.getLocation();
           TabletState state = tls.getState(currentTServers.keySet());
 
-          TabletLogger.missassigned(tls.extent, goal.toString(), state.toString(), tls.future,
-              tls.current, tls.walogs.size());
+          TabletLogger.missassigned(tls.extent, goal.toString(), state.toString(),
+              tls.getFutureServer(), tls.getCurrentServer(), tls.walogs.size());
 
           stats.update(tableId, state);
           mergeStats.update(tls.extent, state, tls.chopped, !tls.walogs.isEmpty());
@@ -265,12 +265,14 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
 
           if (goal == TabletGoalState.HOSTED) {
             if ((state != TabletState.HOSTED && !tls.walogs.isEmpty())
-                && manager.recoveryManager.recoverLogs(tls.extent, tls.walogs))
+                && manager.recoveryManager.recoverLogs(tls.extent, tls.walogs)) {
               continue;
+            }
             switch (state) {
               case HOSTED:
-                if (location.equals(manager.migrations.get(tls.extent)))
+                if (location.getServerInstance().equals(manager.migrations.get(tls.extent))) {
                   manager.migrations.remove(tls.extent);
+                }
                 break;
               case ASSIGNED_TO_DEAD_SERVER:
                 hostDeadTablet(tLists, tls, location, wals);
@@ -279,11 +281,11 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
                 hostSuspendedTablet(tLists, tls, location, tableConf);
                 break;
               case UNASSIGNED:
-                hostUnassignedTablet(tLists, tls.extent, location);
+                hostUnassignedTablet(tLists, tls.extent, new UnassignedTablet(location, tls.last));
                 break;
               case ASSIGNED:
                 // Send another reminder
-                tLists.assigned.add(new Assignment(tls.extent, tls.future));
+                tLists.assigned.add(new Assignment(tls.extent, tls.getFutureServer(), tls.last));
                 break;
             }
           } else {
@@ -300,7 +302,8 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
                 unassignDeadTablet(tLists, tls, wals);
                 break;
               case HOSTED:
-                TServerConnection client = manager.tserverSet.getConnection(location);
+                TServerConnection client =
+                    manager.tserverSet.getConnection(location.getServerInstance());
                 if (client != null) {
                   client.unloadTablet(manager.managerLock, tls.extent, goal.howUnload(),
                       manager.getSteadyTime());
@@ -371,32 +374,32 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
   private void unassignDeadTablet(TabletLists tLists, TabletLocationState tls, WalStateManager wals)
       throws WalMarkerException {
     tLists.assignedToDeadServers.add(tls);
-    if (!tLists.logsForDeadServers.containsKey(tls.futureOrCurrent())) {
-      tLists.logsForDeadServers.put(tls.futureOrCurrent(),
-          wals.getWalsInUse(tls.futureOrCurrent()));
+    if (!tLists.logsForDeadServers.containsKey(tls.futureOrCurrentServer())) {
+      tLists.logsForDeadServers.put(tls.futureOrCurrentServer(),
+          wals.getWalsInUse(tls.futureOrCurrentServer()));
     }
   }
 
   private void hostUnassignedTablet(TabletLists tLists, KeyExtent tablet,
-      TServerInstance location) {
+      UnassignedTablet unassignedTablet) {
     // maybe it's a finishing migration
     TServerInstance dest = manager.migrations.get(tablet);
     if (dest != null) {
       // if destination is still good, assign it
       if (tLists.destinations.containsKey(dest)) {
-        tLists.assignments.add(new Assignment(tablet, dest));
+        tLists.assignments.add(new Assignment(tablet, dest, unassignedTablet.getLastLocation()));
       } else {
         // get rid of this migration
         manager.migrations.remove(tablet);
-        tLists.unassigned.put(tablet, location);
+        tLists.unassigned.put(tablet, unassignedTablet);
       }
     } else {
-      tLists.unassigned.put(tablet, location);
+      tLists.unassigned.put(tablet, unassignedTablet);
     }
   }
 
-  private void hostSuspendedTablet(TabletLists tLists, TabletLocationState tls,
-      TServerInstance location, TableConfiguration tableConf) {
+  private void hostSuspendedTablet(TabletLists tLists, TabletLocationState tls, Location location,
+      TableConfiguration tableConf) {
     if (manager.getSteadyTime() - tls.suspend.suspensionTime
         < tableConf.getTimeInMillis(Property.TABLE_SUSPEND_DURATION)) {
       // Tablet is suspended. See if its tablet server is back.
@@ -412,22 +415,23 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
 
       // Old tablet server is back. Return this tablet to its previous owner.
       if (returnInstance != null) {
-        tLists.assignments.add(new Assignment(tls.extent, returnInstance));
+        tLists.assignments.add(new Assignment(tls.extent, returnInstance, tls.last));
       }
       // else - tablet server not back. Don't ask for a new assignment right now.
 
     } else {
       // Treat as unassigned, ask for a new assignment.
-      tLists.unassigned.put(tls.extent, location);
+      tLists.unassigned.put(tls.extent, new UnassignedTablet(location, tls.last));
     }
   }
 
-  private void hostDeadTablet(TabletLists tLists, TabletLocationState tls, TServerInstance location,
+  private void hostDeadTablet(TabletLists tLists, TabletLocationState tls, Location location,
       WalStateManager wals) throws WalMarkerException {
     tLists.assignedToDeadServers.add(tls);
-    if (location.equals(manager.migrations.get(tls.extent)))
+    if (location.getServerInstance().equals(manager.migrations.get(tls.extent))) {
       manager.migrations.remove(tls.extent);
-    TServerInstance tserver = tls.futureOrCurrent();
+    }
+    TServerInstance tserver = tls.futureOrCurrentServer();
     if (!tLists.logsForDeadServers.containsKey(tserver)) {
       tLists.logsForDeadServers.put(tserver, wals.getWalsInUse(tserver));
     }
@@ -451,8 +455,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
       Map<Key,Value> assigned = new HashMap<>();
       KeyExtent extent = KeyExtent.fromMetaRow(row);
       String table = MetadataTable.NAME;
-      if (extent.isMeta())
+      if (extent.isMeta()) {
         table = RootTable.NAME;
+      }
       Scanner scanner = manager.getContext().createScanner(table, Authorizations.EMPTY);
       scanner.fetchColumnFamily(CurrentLocationColumnFamily.NAME);
       scanner.fetchColumnFamily(FutureLocationColumnFamily.NAME);
@@ -508,29 +513,36 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
 
   private void sendSplitRequest(MergeInfo info, TabletState state, TabletLocationState tls) {
     // Already split?
-    if (!info.getState().equals(MergeState.SPLITTING))
+    if (!info.getState().equals(MergeState.SPLITTING)) {
       return;
+    }
     // Merges don't split
-    if (!info.isDelete())
+    if (!info.isDelete()) {
       return;
+    }
     // Online and ready to split?
-    if (!state.equals(TabletState.HOSTED))
+    if (!state.equals(TabletState.HOSTED)) {
       return;
+    }
     // Does this extent cover the end points of the delete?
     KeyExtent range = info.getExtent();
     if (tls.extent.overlaps(range)) {
       for (Text splitPoint : new Text[] {range.prevEndRow(), range.endRow()}) {
-        if (splitPoint == null)
+        if (splitPoint == null) {
           continue;
-        if (!tls.extent.contains(splitPoint))
+        }
+        if (!tls.extent.contains(splitPoint)) {
           continue;
-        if (splitPoint.equals(tls.extent.endRow()))
+        }
+        if (splitPoint.equals(tls.extent.endRow())) {
           continue;
-        if (splitPoint.equals(tls.extent.prevEndRow()))
+        }
+        if (splitPoint.equals(tls.extent.prevEndRow())) {
           continue;
+        }
         try {
           TServerConnection conn;
-          conn = manager.tserverSet.getConnection(tls.current);
+          conn = manager.tserverSet.getConnection(tls.getCurrentServer());
           if (conn != null) {
             Manager.log.info("Asking {} to split {} at {}", tls.current, tls.extent, splitPoint);
             conn.splitTablet(tls.extent, splitPoint);
@@ -548,19 +560,22 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
 
   private void sendChopRequest(MergeInfo info, TabletState state, TabletLocationState tls) {
     // Don't bother if we're in the wrong state
-    if (!info.getState().equals(MergeState.WAITING_FOR_CHOPPED))
+    if (!info.getState().equals(MergeState.WAITING_FOR_CHOPPED)) {
       return;
+    }
     // Tablet must be online
-    if (!state.equals(TabletState.HOSTED))
+    if (!state.equals(TabletState.HOSTED)) {
       return;
+    }
     // Tablet isn't already chopped
-    if (tls.chopped)
+    if (tls.chopped) {
       return;
+    }
     // Tablet ranges intersect
     if (info.needsToBeChopped(tls.extent)) {
       TServerConnection conn;
       try {
-        conn = manager.tserverSet.getConnection(tls.current);
+        conn = manager.tserverSet.getConnection(tls.getCurrentServer());
         if (conn != null) {
           Manager.log.info("Asking {} to chop {}", tls.current, tls.extent);
           conn.chop(manager.managerLock, tls.extent);
@@ -581,8 +596,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
         // starting the merge... the verification check that is done before
         // moving into the merging state could fail if merge starts but does
         // not finish
-        if (update == MergeState.COMPLETE)
+        if (update == MergeState.COMPLETE) {
           update = MergeState.NONE;
+        }
         if (update != stats.getMergeInfo().getState()) {
           manager.setMergeState(stats.getMergeInfo(), update);
         }
@@ -759,8 +775,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
         }
       }
 
-      if (maxLogicalTime != null)
+      if (maxLogicalTime != null) {
         ServerColumnFamily.TIME_COLUMN.put(m, new Value(maxLogicalTime.encode()));
+      }
 
       // delete any entries for external compactions
       extCompIds.forEach(ecid -> m.putDelete(ExternalCompactionColumnFamily.STR_NAME, ecid));
@@ -818,8 +835,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
         Entry<Key,Value> entry = row.next();
         Key key = entry.getKey();
 
-        if (m == null)
+        if (m == null) {
           m = new Mutation(key.getRow());
+        }
 
         m.putDelete(key.getColumnFamily(), key.getColumnQualifier());
         Manager.log.debug("deleting entry {}", key);
@@ -883,21 +901,23 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
   }
 
   private void getAssignmentsFromBalancer(TabletLists tLists,
-      Map<KeyExtent,TServerInstance> unassigned) {
-    if (!tLists.currentTServers.isEmpty()) {
+      Map<KeyExtent,UnassignedTablet> unassigned) {
+    if (!tLists.destinations.isEmpty()) {
       Map<KeyExtent,TServerInstance> assignedOut = new HashMap<>();
-      manager.getAssignments(tLists.currentTServers, unassigned, assignedOut);
+      manager.getAssignments(tLists.destinations, unassigned, assignedOut);
       for (Entry<KeyExtent,TServerInstance> assignment : assignedOut.entrySet()) {
         if (unassigned.containsKey(assignment.getKey())) {
           if (assignment.getValue() != null) {
-            if (!tLists.currentTServers.containsKey(assignment.getValue())) {
+            if (!tLists.destinations.containsKey(assignment.getValue())) {
               Manager.log.warn(
                   "balancer assigned {} to a tablet server that is not current {} ignoring",
                   assignment.getKey(), assignment.getValue());
               continue;
             }
 
-            tLists.assignments.add(new Assignment(assignment.getKey(), assignment.getValue()));
+            final UnassignedTablet unassignedTablet = unassigned.get(assignment.getKey());
+            tLists.assignments.add(new Assignment(assignment.getKey(), assignment.getValue(),
+                unassignedTablet != null ? unassignedTablet.getLastLocation() : null));
           }
         } else {
           Manager.log.warn(
@@ -906,8 +926,9 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
         }
       }
 
-      if (!unassigned.isEmpty() && assignedOut.isEmpty())
+      if (!unassigned.isEmpty() && assignedOut.isEmpty()) {
         Manager.log.warn("Load balancer failed to assign any tablets");
+      }
     }
   }
 
@@ -943,4 +964,5 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
       }
     }
   }
+
 }
