@@ -34,6 +34,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Objects;
+import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.BiConsumer;
 
@@ -53,7 +54,6 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
-import org.apache.accumulo.core.fate.zookeeper.ZooUtil;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
 import org.apache.accumulo.core.file.FileOperations;
@@ -70,7 +70,7 @@ import org.apache.accumulo.core.metadata.schema.MetadataSchema.DeletesSection.Sk
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataTime;
 import org.apache.accumulo.core.metadata.schema.RootTabletMetadata;
-import org.apache.accumulo.core.metadata.schema.TabletMetadata.LocationType;
+import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.spi.compaction.SimpleCompactionDispatcher;
 import org.apache.accumulo.core.spi.crypto.NoCryptoServiceFactory;
@@ -94,7 +94,6 @@ import org.apache.zookeeper.ZKUtil;
 import org.apache.zookeeper.ZooDefs;
 import org.apache.zookeeper.ZooKeeper;
 import org.apache.zookeeper.data.ACL;
-import org.apache.zookeeper.data.Id;
 import org.apache.zookeeper.data.Stat;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -143,33 +142,38 @@ public class Upgrader9to10 implements Upgrader {
     createScanServerNodes(context);
   }
 
+  private static String extractAuthName(ACL acl) {
+    Objects.requireNonNull(acl, "provided ACL cannot be null");
+    try {
+      return acl.getId().getId().trim().split(":")[0];
+    } catch (Exception ex) {
+      log.debug("Invalid ACL passed, cannot parse id from '{}'", acl);
+      return "";
+    }
+  }
+
+  private static boolean hasAllPermissions(final Set<String> users, final List<ACL> acls) {
+    return acls.stream()
+        .anyMatch(a -> users.contains(extractAuthName(a)) && a.getPerms() == ZooDefs.Perms.ALL);
+  }
+
   private void validateACLs(ServerContext context) {
 
     final AtomicBoolean aclErrorOccurred = new AtomicBoolean(false);
     final ZooReaderWriter zrw = context.getZooReaderWriter();
     final ZooKeeper zk = zrw.getZooKeeper();
     final String rootPath = context.getZooKeeperRoot();
-
-    final Id zkDigest =
-        ZooUtil.getZkDigestAuthId(context.getConfiguration().get(Property.INSTANCE_SECRET));
-    final List<ACL> privateWithAuth = new ArrayList<>();
-    privateWithAuth.add(new ACL(ZooDefs.Perms.ALL, zkDigest));
-    final List<ACL> publicWithAuth = new ArrayList<>(privateWithAuth);
-    publicWithAuth.add(new ACL(ZooDefs.Perms.READ, ZooDefs.Ids.ANYONE_ID_UNSAFE));
+    final Set<String> users = Set.of("accumulo", "anyone");
 
     try {
       ZKUtil.visitSubTreeDFS(zk, rootPath, false, (rc, path, ctx, name) -> {
         try {
-          final Stat stat = new Stat();
-          final List<ACL> acls = zk.getACL(path, stat);
-
-          if (((path.equals(Constants.ZROOT) || path.equals(Constants.ZROOT + Constants.ZINSTANCES))
-              && !acls.equals(ZooDefs.Ids.OPEN_ACL_UNSAFE))
-              || (!privateWithAuth.equals(acls) && !publicWithAuth.equals(acls))) {
-            log.error("ZNode at {} has unexpected ACL: {}", path, acls);
+          final List<ACL> acls = zk.getACL(path, new Stat());
+          if (!hasAllPermissions(users, acls)) {
+            log.error(
+                "ZNode at {} does not have an ACL that allows accumulo to write to it. ZNode ACL will need to be modified. Current ACLs: {}",
+                path, acls);
             aclErrorOccurred.set(true);
-          } else {
-            log.trace("ZNode at {} has expected ACL.", path);
           }
         } catch (KeeperException | InterruptedException e) {
           log.error("Error getting ACL for path: {}", path, e);
@@ -177,9 +181,10 @@ public class Upgrader9to10 implements Upgrader {
         }
       });
       if (aclErrorOccurred.get()) {
-        throw new RuntimeException("Upgrade Failed! Error validating ZNode ACLs. "
-            + "Check the log for specific failed paths, check ZooKeeper troubleshooting in user documentation "
-            + "for instructions on how to fix.");
+        throw new RuntimeException(
+            "Upgrade precondition failed! ACLs will need to be modified for some ZooKeeper nodes. "
+                + "Check the log for specific failed paths, check ZooKeeper troubleshooting in user documentation "
+                + "for instructions on how to fix.");
       }
     } catch (KeeperException | InterruptedException e) {
       throw new RuntimeException("Upgrade Failed! Error validating nodes under " + rootPath, e);
@@ -283,14 +288,17 @@ public class Upgrader9to10 implements Upgrader {
 
       tabletMutator.putDirName(upgradeDirColumn(dir));
 
-      if (last != null)
-        tabletMutator.putLocation(last, LocationType.LAST);
+      if (last != null) {
+        tabletMutator.putLocation(Location.last(last));
+      }
 
-      if (future != null)
-        tabletMutator.putLocation(future, LocationType.FUTURE);
+      if (future != null) {
+        tabletMutator.putLocation(Location.future(future));
+      }
 
-      if (current != null)
-        tabletMutator.putLocation(current, LocationType.CURRENT);
+      if (current != null) {
+        tabletMutator.putLocation(Location.current(current));
+      }
 
       logs.forEach(tabletMutator::putWal);
 
@@ -409,8 +417,9 @@ public class Upgrader9to10 implements Upgrader {
   private String getFromZK(ServerContext context, String relpath) {
     try {
       byte[] data = context.getZooReaderWriter().getData(context.getZooKeeperRoot() + relpath);
-      if (data == null)
+      if (data == null) {
         return null;
+      }
 
       return new String(data, UTF_8);
     } catch (NoNodeException e) {
@@ -489,8 +498,9 @@ public class Upgrader9to10 implements Upgrader {
               path.substring(0, path.lastIndexOf("/delete+")) + "/" + filename.split("\\+")[1];
           if (fs.exists(new Path(expectedCompactedFile))) {
             // compaction finished, but did not finish deleting compacted files.. so delete it
-            if (!fs.deleteRecursively(file.getPath()))
+            if (!fs.deleteRecursively(file.getPath())) {
               log.warn("Delete of file: {} return false", file.getPath());
+            }
             continue;
           }
           // compaction did not finish, so put files back
@@ -508,8 +518,9 @@ public class Upgrader9to10 implements Upgrader {
 
         if (filename.endsWith("_tmp")) {
           log.warn("cleaning up old tmp file: {}", path);
-          if (!fs.deleteRecursively(file.getPath()))
+          if (!fs.deleteRecursively(file.getPath())) {
             log.warn("Delete of tmp file: {} return false", file.getPath());
+          }
 
           continue;
         }
@@ -801,14 +812,15 @@ public class Upgrader9to10 implements Upgrader {
 
     // if the volume was removed properly, the path is absolute so return, otherwise
     // it is a relative path so proceed with more checks
-    if (pathNoVolume != null)
+    if (pathNoVolume != null) {
       return pathToCheck;
+    }
 
     // A relative path directory of the form "/tableId/tabletDir" will have depth == 2
     // A relative path file of the form "/tableId/tabletDir/file" will have depth == 3
     Preconditions.checkState(
         oldDelete.startsWith("/") && (pathToCheck.depth() == 2 || pathToCheck.depth() == 3),
-        "Unrecognized relative delete marker {}", oldDelete);
+        "Unrecognized relative delete marker (%s)", oldDelete);
 
     // found relative paths so verify the property used to build the absolute paths
     if (upgradeProperty == null || upgradeProperty.isBlank()) {
