@@ -212,9 +212,9 @@ public class CompactableImpl implements Compactable {
       this.selectionExpirationDeriver = selectionExpirationDeriver;
       allCompactingFiles.addAll(extCompactingFiles);
       if (extSelInfo.isPresent()) {
-        this.selectedFiles.addAll(extSelInfo.get().selectedFiles);
-        this.selectKind = extSelInfo.get().selectKind;
-        this.initiallySelectedAll = extSelInfo.get().initiallySelectedAll;
+        this.selectedFiles.addAll(extSelInfo.orElseThrow().selectedFiles);
+        this.selectKind = extSelInfo.orElseThrow().selectKind;
+        this.initiallySelectedAll = extSelInfo.orElseThrow().initiallySelectedAll;
         this.selectStatus = FileSelectionStatus.RESERVED;
 
         log.debug("Selected compaction status initialized from external compactions {} {} {} {}",
@@ -393,8 +393,9 @@ public class CompactableImpl implements Compactable {
 
       switch (kind) {
         case SYSTEM: {
-          if (isCompactionStratConfigured)
+          if (isCompactionStratConfigured) {
             return Set.of();
+          }
 
           return handleSystemCompaction(currFiles);
         }
@@ -418,14 +419,16 @@ public class CompactableImpl implements Compactable {
           return Set.of();
         case SELECTED: {
           if (selectStatus == FileSelectionStatus.NEW
-              || selectStatus == FileSelectionStatus.SELECTING)
+              || selectStatus == FileSelectionStatus.SELECTING) {
             return Set.of();
+          }
 
           var filesToChop = getFilesToChop(currFiles);
           filesToChop.removeAll(allCompactingFiles);
           if (selectStatus == FileSelectionStatus.SELECTED
-              || selectStatus == FileSelectionStatus.RESERVED)
+              || selectStatus == FileSelectionStatus.RESERVED) {
             filesToChop.removeAll(selectedFiles);
+          }
           return Collections.unmodifiableSet(filesToChop);
         }
         default:
@@ -573,15 +576,14 @@ public class CompactableImpl implements Compactable {
     /**
      * Releases a set of files that were previously reserved for compaction.
      *
-     * @param newFile
-     *          The file produced by a compaction. If the compaction failed, this can be null.
+     * @param newFile The file produced by a compaction. If the compaction failed, this can be null.
      */
     void completed(CompactionJob job, Set<StoredTabletFile> jobFiles,
         Optional<StoredTabletFile> newFile) {
       Preconditions.checkArgument(!jobFiles.isEmpty());
       Preconditions.checkState(allCompactingFiles.removeAll(jobFiles));
       if (newFile.isPresent()) {
-        choppedFiles.add(newFile.get());
+        choppedFiles.add(newFile.orElseThrow());
       }
 
       if ((job.getKind() == CompactionKind.USER || job.getKind() == CompactionKind.SELECTOR)) {
@@ -605,7 +607,7 @@ public class CompactableImpl implements Compactable {
         log.trace("Selected compaction status changed {} {}", getExtent(), selectStatus);
       } else if (selectStatus == FileSelectionStatus.RESERVED) {
         if (newFile.isPresent()) {
-          selectedFiles.add(newFile.get());
+          selectedFiles.add(newFile.orElseThrow());
         }
         log.trace("Compacted subset of selected files {} {} -> {}", getExtent(),
             asFileNames(jobFiles), newFile.orElse(null));
@@ -643,13 +645,15 @@ public class CompactableImpl implements Compactable {
             dataFileSizes.keySet(), extCompactionsToRemove);
 
     if (extSelInfo.isPresent()) {
-      if (extSelInfo.get().selectKind == CompactionKind.USER) {
-        this.chelper = CompactableUtils.getHelper(extSelInfo.get().selectKind, tablet,
-            tabletCompactionId.get().get().getFirst(), tabletCompactionId.get().get().getSecond());
-        this.compactionConfig = tabletCompactionId.get().get().getSecond();
-        this.compactionId = tabletCompactionId.get().get().getFirst();
-      } else if (extSelInfo.get().selectKind == CompactionKind.SELECTOR) {
-        this.chelper = CompactableUtils.getHelper(extSelInfo.get().selectKind, tablet, null, null);
+      if (extSelInfo.orElseThrow().selectKind == CompactionKind.USER) {
+        this.chelper = CompactableUtils.getHelper(extSelInfo.orElseThrow().selectKind, tablet,
+            tabletCompactionId.get().orElseThrow().getFirst(),
+            tabletCompactionId.get().orElseThrow().getSecond());
+        this.compactionConfig = tabletCompactionId.get().orElseThrow().getSecond();
+        this.compactionId = tabletCompactionId.get().orElseThrow().getFirst();
+      } else if (extSelInfo.orElseThrow().selectKind == CompactionKind.SELECTOR) {
+        this.chelper =
+            CompactableUtils.getHelper(extSelInfo.orElseThrow().selectKind, tablet, null, null);
       }
     }
 
@@ -824,8 +828,9 @@ public class CompactableImpl implements Compactable {
   }
 
   private void initiateSelection(CompactionKind kind) {
-    if (kind != CompactionKind.SELECTOR)
+    if (kind != CompactionKind.SELECTOR) {
       return;
+    }
 
     initiateSelection(CompactionKind.SELECTOR, null, null);
   }
@@ -833,8 +838,9 @@ public class CompactableImpl implements Compactable {
   private void checkIfUserCompactionCanceled() {
 
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return;
+      }
 
       if (!fileMgr.isSelected(CompactionKind.USER)) {
         return;
@@ -976,7 +982,7 @@ public class CompactableImpl implements Compactable {
       if (compactionId.isEmpty()) {
         unexpectedExternal = true;
         reasons.add("No compaction id in zookeeper");
-      } else if (!compactionId.get().equals(cid)) {
+      } else if (!compactionId.orElseThrow().equals(cid)) {
         unexpectedExternal = true;
         reasons.add("Compaction id mismatch with zookeeper");
       }
@@ -991,8 +997,9 @@ public class CompactableImpl implements Compactable {
       return Optional.empty();
     }
 
-    if (extKind != null)
+    if (extKind != null) {
       return Optional.of(new SelectedInfo(initiallySelAll, tmpSelectedFiles, extKind));
+    }
 
     return Optional.empty();
   }
@@ -1003,12 +1010,14 @@ public class CompactableImpl implements Compactable {
 
     var localHelper = CompactableUtils.getHelper(kind, tablet, compactionId, compactionConfig);
 
-    if (localHelper == null)
+    if (localHelper == null) {
       return;
+    }
 
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return;
+      }
 
       if (fileMgr.initiateSelection(kind)) {
         this.chelper = localHelper;
@@ -1089,8 +1098,9 @@ public class CompactableImpl implements Compactable {
   @Override
   public Optional<Files> getFiles(CompactionServiceId service, CompactionKind kind) {
 
-    if (!service.equals(getConfiguredService(kind)))
+    if (!service.equals(getConfiguredService(kind))) {
       return Optional.empty();
+    }
 
     servicesUsed.add(service);
 
@@ -1099,13 +1109,15 @@ public class CompactableImpl implements Compactable {
     // very important to call following outside of lock
     initiateSelection(kind);
 
-    if (kind == CompactionKind.USER)
+    if (kind == CompactionKind.USER) {
       checkIfUserCompactionCanceled();
+    }
 
     synchronized (this) {
 
-      if (closed)
+      if (closed) {
         return Optional.empty();
+      }
 
       var runningJobsCopy = Set.copyOf(runningJobs);
 
@@ -1133,8 +1145,9 @@ public class CompactableImpl implements Compactable {
       }, 3, TimeUnit.SECONDS);
       this.inexpensiveCheck = Suppliers.memoizeWithExpiration(() -> {
         if (closed
-            || (kind == CompactionKind.USER && lastSeenCompactionCancelId.get() >= compactionId))
+            || (kind == CompactionKind.USER && lastSeenCompactionCancelId.get() >= compactionId)) {
           return false;
+        }
         return true;
       }, 50, TimeUnit.MILLISECONDS);
     }
@@ -1168,21 +1181,26 @@ public class CompactableImpl implements Compactable {
     cInfo.jobFiles = job.getFiles().stream()
         .map(cf -> ((CompactableFileImpl) cf).getStoredTabletFile()).collect(Collectors.toSet());
 
-    if (job.getKind() == CompactionKind.USER)
+    if (job.getKind() == CompactionKind.USER) {
       checkIfUserCompactionCanceled();
+    }
 
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return Optional.empty();
+      }
 
-      if (runningJobs.contains(job))
+      if (runningJobs.contains(job)) {
         return Optional.empty();
+      }
 
-      if (!service.equals(getConfiguredService(job.getKind())))
+      if (!service.equals(getConfiguredService(job.getKind()))) {
         return Optional.empty();
+      }
 
-      if (!fileMgr.reserveFiles(job, cInfo.jobFiles))
+      if (!fileMgr.reserveFiles(job, cInfo.jobFiles)) {
         return Optional.empty();
+      }
 
       if (!addJob(job)) {
         throw new AssertionError();
@@ -1258,10 +1276,11 @@ public class CompactableImpl implements Compactable {
       RateLimiter writeLimiter, long queuedTime) {
 
     Optional<CompactionInfo> ocInfo = reserveFilesForCompaction(service, job);
-    if (ocInfo.isEmpty())
+    if (ocInfo.isEmpty()) {
       return;
+    }
 
-    var cInfo = ocInfo.get();
+    var cInfo = ocInfo.orElseThrow();
     Optional<StoredTabletFile> newFile = Optional.empty();
     long startTime = System.currentTimeMillis();
     CompactionKind kind = job.getKind();
@@ -1307,10 +1326,11 @@ public class CompactableImpl implements Compactable {
     Preconditions.checkState(!tablet.getExtent().isMeta());
 
     Optional<CompactionInfo> ocInfo = reserveFilesForCompaction(service, job);
-    if (ocInfo.isEmpty())
+    if (ocInfo.isEmpty()) {
       return null;
+    }
 
-    var cInfo = ocInfo.get();
+    var cInfo = ocInfo.orElseThrow();
 
     try {
       Map<String,String> overrides =
@@ -1354,8 +1374,9 @@ public class CompactableImpl implements Compactable {
       long entries) {
 
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return;
+      }
 
       // defend against multiple threads trying to commit the same ECID and force tablet close to
       // wait on any pending commits
@@ -1407,8 +1428,9 @@ public class CompactableImpl implements Compactable {
   public void externalCompactionFailed(ExternalCompactionId ecid) {
 
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return;
+      }
 
       if (!externalCompactionsCommitting.add(ecid)) {
         return;
@@ -1523,8 +1545,9 @@ public class CompactableImpl implements Compactable {
    */
   public synchronized void close() {
     synchronized (this) {
-      if (closed)
+      if (closed) {
         return;
+      }
 
       closed = true;
 
