@@ -39,10 +39,10 @@ import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.logging.TabletLogger;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
+import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.MapCounter;
 import org.apache.accumulo.core.util.Pair;
@@ -124,22 +124,26 @@ class DatafileManager {
     synchronized (tablet) {
       Set<StoredTabletFile> absFilePaths = scanFileReservations.remove(reservationId);
 
-      if (absFilePaths == null)
+      if (absFilePaths == null) {
         throw new IllegalArgumentException("Unknown scan reservation id " + reservationId);
+      }
 
       boolean notify = false;
       for (StoredTabletFile path : absFilePaths) {
         long refCount = fileScanReferenceCounts.decrement(path, 1);
         if (refCount == 0) {
-          if (filesToDeleteAfterScan.remove(path))
+          if (filesToDeleteAfterScan.remove(path)) {
             filesToDelete.add(path);
+          }
           notify = true;
-        } else if (refCount < 0)
+        } else if (refCount < 0) {
           throw new IllegalStateException("Scan ref count for " + path + " is " + refCount);
+        }
       }
 
-      if (notify)
+      if (notify) {
         tablet.notifyAll();
+      }
     }
 
     if (!filesToDelete.isEmpty()) {
@@ -150,17 +154,19 @@ class DatafileManager {
   }
 
   void removeFilesAfterScan(Set<StoredTabletFile> scanFiles) {
-    if (scanFiles.isEmpty())
+    if (scanFiles.isEmpty()) {
       return;
+    }
 
     Set<StoredTabletFile> filesToDelete = new HashSet<>();
 
     synchronized (tablet) {
       for (StoredTabletFile path : scanFiles) {
-        if (fileScanReferenceCounts.get(path) == 0)
+        if (fileScanReferenceCounts.get(path) == 0) {
           filesToDelete.add(path);
-        else
+        } else {
           filesToDeleteAfterScan.add(path);
+        }
       }
     }
 
@@ -191,8 +197,9 @@ class DatafileManager {
         }
 
         for (StoredTabletFile path : pathsToWaitFor) {
-          if (fileScanReferenceCounts.get(path) > 0)
+          if (fileScanReferenceCounts.get(path) > 0) {
             inUse.add(path);
+          }
         }
       }
     } catch (Exception e) {
@@ -224,40 +231,41 @@ class DatafileManager {
         throw new IOException("Data file " + tpath + " not in table dirs");
       }
 
-      if (bulkDir == null)
+      if (bulkDir == null) {
         bulkDir = tpath.getTabletDir();
-      else if (!bulkDir.equals(tpath.getTabletDir()))
+      } else if (!bulkDir.equals(tpath.getTabletDir())) {
         throw new IllegalArgumentException("bulk files in different dirs " + bulkDir + " " + tpath);
+      }
 
     }
 
     if (tablet.getExtent().isMeta()) {
       throw new IllegalArgumentException("Can not import files to a metadata tablet");
     }
-
-    synchronized (bulkFileImportLock) {
-
-      if (!paths.isEmpty()) {
-        long bulkTime = Long.MIN_VALUE;
-        if (setTime) {
-          for (DataFileValue dfv : paths.values()) {
-            long nextTime = tablet.getAndUpdateTime();
-            if (nextTime < bulkTime)
-              throw new IllegalStateException(
-                  "Time went backwards unexpectedly " + nextTime + " " + bulkTime);
-            bulkTime = nextTime;
-            dfv.setTime(bulkTime);
-          }
-        }
-
-        newFiles = tablet.updatePersistedTime(bulkTime, paths, tid);
-      }
-    }
-
     // increment start count before metadata update AND updating in memory map of files
     metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementStart);
     // do not place any code here between above stmt and try{}finally
     try {
+      synchronized (bulkFileImportLock) {
+
+        if (!paths.isEmpty()) {
+          long bulkTime = Long.MIN_VALUE;
+          if (setTime) {
+            for (DataFileValue dfv : paths.values()) {
+              long nextTime = tablet.getAndUpdateTime();
+              if (nextTime < bulkTime) {
+                throw new IllegalStateException(
+                    "Time went backwards unexpectedly " + nextTime + " " + bulkTime);
+              }
+              bulkTime = nextTime;
+              dfv.setTime(bulkTime);
+            }
+          }
+
+          newFiles = tablet.updatePersistedTime(bulkTime, paths, tid);
+        }
+      }
+
       synchronized (tablet) {
         for (Entry<StoredTabletFile,DataFileValue> tpath : newFiles.entrySet()) {
           if (datafileSizes.containsKey(tpath.getKey())) {
@@ -341,41 +349,43 @@ class DatafileManager {
         logFileOnly.add(unusedWalLog);
       }
     }
-    try {
-      // the order of writing to metadata and walog is important in the face of machine/process
-      // failures need to write to metadata before writing to walog, when things are done in the
-      // reverse order data could be lost... the minor compaction start even should be written
-      // before the following metadata write is made
-      newFile = tablet.updateTabletDataFile(commitSession.getMaxCommittedTime(), newDatafile, dfv,
-          unusedWalLogs, flushId);
-
-      // Mark that we have data we want to replicate
-      // This WAL could still be in use by other Tablets *from the same table*, so we can only mark
-      // that there is data to replicate,
-      // but it is *not* closed. We know it is not closed by the fact that this MinC triggered. A
-      // MinC cannot happen unless the
-      // tablet is online and thus these WALs are referenced by that tablet. Therefore, the WAL
-      // replication status cannot be 'closed'.
-      if (replicate) {
-        if (log.isDebugEnabled()) {
-          log.debug("Recording that data has been ingested into {} using {}", tablet.getExtent(),
-              logFileOnly);
-        }
-        for (String logFile : logFileOnly) {
-          @SuppressWarnings("deprecation")
-          Status status = org.apache.accumulo.server.replication.StatusUtil.openWithUnknownLength();
-          ReplicationTableUtil.updateFiles(tablet.getContext(), tablet.getExtent(), logFile,
-              status);
-        }
-      }
-    } finally {
-      tablet.finishClearingUnusedLogs();
-    }
 
     // increment start count before metadata update AND updating in memory map of files
     metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementStart);
     // do not place any code here between above stmt and try{}finally
     try {
+      try {
+        // the order of writing to metadata and walog is important in the face of machine/process
+        // failures need to write to metadata before writing to walog, when things are done in the
+        // reverse order data could be lost... the minor compaction start even should be written
+        // before the following metadata write is made
+        newFile = tablet.updateTabletDataFile(commitSession.getMaxCommittedTime(), newDatafile, dfv,
+            unusedWalLogs, flushId);
+
+        // Mark that we have data we want to replicate
+        // This WAL could still be in use by other Tablets *from the same table*, so we can only
+        // mark
+        // that there is data to replicate,
+        // but it is *not* closed. We know it is not closed by the fact that this MinC triggered. A
+        // MinC cannot happen unless the
+        // tablet is online and thus these WALs are referenced by that tablet. Therefore, the WAL
+        // replication status cannot be 'closed'.
+        if (replicate) {
+          if (log.isDebugEnabled()) {
+            log.debug("Recording that data has been ingested into {} using {}", tablet.getExtent(),
+                logFileOnly);
+          }
+          for (String logFile : logFileOnly) {
+            @SuppressWarnings("deprecation")
+            Status status =
+                org.apache.accumulo.server.replication.StatusUtil.openWithUnknownLength();
+            ReplicationTableUtil.updateFiles(tablet.getContext(), tablet.getExtent(), logFile,
+                status);
+          }
+        }
+      } finally {
+        tablet.finishClearingUnusedLogs();
+      }
 
       do {
         try {
@@ -394,8 +404,8 @@ class DatafileManager {
       synchronized (tablet) {
         t1 = System.currentTimeMillis();
 
-        if (dfv.getNumEntries() > 0 && newFile.isPresent()) {
-          StoredTabletFile newFileStored = newFile.get();
+        if (newFile.isPresent()) {
+          StoredTabletFile newFileStored = newFile.orElseThrow();
           if (datafileSizes.containsKey(newFileStored)) {
             log.error("Adding file that is already in set {}", newFileStored);
           }
@@ -448,7 +458,7 @@ class DatafileManager {
       rename(vm, tmpDatafile.getPath(), newDatafile.getPath());
     }
 
-    TServerInstance lastLocation = null;
+    Location lastLocation = null;
     Optional<StoredTabletFile> newFile;
 
     if (dfv.getNumEntries() > 0) {
@@ -471,7 +481,7 @@ class DatafileManager {
             "Compacted files %s are not a subset of tablet files %s", oldDatafiles,
             datafileSizes.keySet());
         if (newFile.isPresent()) {
-          Preconditions.checkState(!datafileSizes.containsKey(newFile.get()),
+          Preconditions.checkState(!datafileSizes.containsKey(newFile.orElseThrow()),
               "New compaction file %s already exist in tablet files %s", newFile,
               datafileSizes.keySet());
         }
@@ -481,7 +491,7 @@ class DatafileManager {
         datafileSizes.keySet().removeAll(oldDatafiles);
 
         if (newFile.isPresent()) {
-          datafileSizes.put(newFile.get(), dfv);
+          datafileSizes.put(newFile.orElseThrow(), dfv);
           // could be used by a follow on compaction in a multipass compaction
         }
 
@@ -498,8 +508,9 @@ class DatafileManager {
 
       // known consistency issue between minor and major compactions - see ACCUMULO-18
       Set<StoredTabletFile> filesInUseByScans = waitForScansToFinish(oldDatafiles);
-      if (!filesInUseByScans.isEmpty())
+      if (!filesInUseByScans.isEmpty()) {
         log.debug("Adding scan refs to metadata {} {}", extent, filesInUseByScans);
+      }
       ManagerMetadataUtil.replaceDatafiles(tablet.getContext(), extent, oldDatafiles,
           filesInUseByScans, newFile, compactionIdToWrite, dfv,
           tablet.getTabletServer().getClientAddressString(), lastLocation,
