@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
 import java.io.IOException;
-import java.util.Map.Entry;
+import java.util.Map;
 
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
@@ -51,20 +53,19 @@ public class CreateNamespaceCommand extends Command {
     shellState.getAccumuloClient().namespaceOperations().create(namespace);
 
     // Copy options if flag was set
-    Iterable<Entry<String,String>> configuration = null;
+    Map<String,String> configuration = null;
     if (cl.hasOption(createNamespaceOptCopyConfig.getOpt())) {
       String copy = cl.getOptionValue(createNamespaceOptCopyConfig.getOpt());
       if (shellState.getAccumuloClient().namespaceOperations().exists(namespace)) {
-        configuration = shellState.getAccumuloClient().namespaceOperations().getProperties(copy);
+        configuration = shellState.getAccumuloClient().namespaceOperations().getConfiguration(copy);
       }
     }
     if (configuration != null) {
-      for (Entry<String,String> entry : configuration) {
-        if (Property.isValidTablePropertyKey(entry.getKey())) {
-          shellState.getAccumuloClient().namespaceOperations().setProperty(namespace,
-              entry.getKey(), entry.getValue());
-        }
-      }
+      final Map<String,String> config = configuration;
+      shellState.getAccumuloClient().namespaceOperations().modifyProperties(namespace,
+          properties -> config.entrySet().stream()
+              .filter(entry -> Property.isValidTablePropertyKey(entry.getKey()))
+              .forEach(entry -> properties.put(entry.getKey(), entry.getValue())));
     }
 
     return 0;
