@@ -1,39 +1,40 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.start.classloader.vfs;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 import java.io.File;
 import java.io.FileWriter;
-import java.io.IOException;
 import java.net.URLClassLoader;
 
 import org.apache.accumulo.start.classloader.AccumuloClassLoader;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.vfs2.FileSystemManager;
 import org.apache.commons.vfs2.impl.VFSClassLoader;
-import org.junit.After;
-import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.junit.runner.RunWith;
-import org.powermock.core.classloader.MockClassLoader;
 import org.powermock.core.classloader.annotations.PowerMockIgnore;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.core.classloader.annotations.SuppressStaticInitializationFor;
@@ -42,6 +43,7 @@ import org.powermock.reflect.Whitebox;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
+@Deprecated
 @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 @RunWith(PowerMockRunner.class)
 @PrepareForTest(AccumuloVFSClassLoader.class)
@@ -52,19 +54,10 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
     "org.apache.hadoop.*", "com.sun.org.apache.xerces.*"})
 public class AccumuloVFSClassLoaderTest {
 
-  private TemporaryFolder folder1 =
+  @Rule
+  public TemporaryFolder folder1 =
       new TemporaryFolder(new File(System.getProperty("user.dir") + "/target"));
 
-  @Before
-  public void setup() throws IOException {
-    folder1.create();
-  }
-
-  @After
-  public void tearDown() {
-    folder1.delete();
-  }
-
   /*
    * Test that the default (empty dynamic class paths) does not create the 2nd level loader
    */
@@ -75,7 +68,7 @@ public class AccumuloVFSClassLoaderTest {
         (AccumuloReloadingVFSClassLoader) null);
 
     File conf = folder1.newFile("accumulo.properties");
-    FileWriter out = new FileWriter(conf);
+    FileWriter out = new FileWriter(conf, UTF_8);
     out.append("general.classpaths=\n");
     out.append("general.vfs.classpaths=\n");
     out.close();
@@ -84,8 +77,10 @@ public class AccumuloVFSClassLoaderTest {
     Whitebox.setInternalState(AccumuloVFSClassLoader.class, "lock", new Object());
     ClassLoader acl = AccumuloVFSClassLoader.getClassLoader();
     assertTrue((acl instanceof URLClassLoader));
-    // no second level means the parent is the system loader (in this case, PowerMock's loader)
-    assertTrue((acl.getParent() instanceof MockClassLoader));
+    // We can't check to see if the parent is an instance of BuiltinClassLoader
+    // Let's assert it's not something we now about
+    assertFalse((acl.getParent() instanceof VFSClassLoader));
+    assertFalse((acl.getParent() instanceof URLClassLoader));
   }
 
   /*
@@ -98,7 +93,7 @@ public class AccumuloVFSClassLoaderTest {
         (AccumuloReloadingVFSClassLoader) null);
 
     File conf = folder1.newFile("accumulo.properties");
-    FileWriter out = new FileWriter(conf);
+    FileWriter out = new FileWriter(conf, UTF_8);
     out.append("general.classpaths=\n");
     out.append("general.vfs.classpaths=\n");
     out.append("general.dynamic.classpaths=" + System.getProperty("user.dir") + "\n");
@@ -125,7 +120,7 @@ public class AccumuloVFSClassLoaderTest {
         folder1.newFile("HelloWorld.jar"));
 
     File conf = folder1.newFile("accumulo.properties");
-    FileWriter out = new FileWriter(conf);
+    FileWriter out = new FileWriter(conf, UTF_8);
     out.append("general.classpaths=\n");
     out.append(
         "general.vfs.classpaths=" + new File(folder1.getRoot(), "HelloWorld.jar").toURI() + "\n");
@@ -142,7 +137,7 @@ public class AccumuloVFSClassLoaderTest {
     // We can't be sure what the authority/host will be due to FQDN mappings, so just check the path
     assertTrue(arvcl.getFileObjects()[0].getURL().toString().contains("HelloWorld.jar"));
     Class<?> clazz1 = arvcl.loadClass("test.HelloWorld");
-    Object o1 = clazz1.newInstance();
+    Object o1 = clazz1.getDeclaredConstructor().newInstance();
     assertEquals("Hello World!", o1.toString());
     Whitebox.setInternalState(AccumuloVFSClassLoader.class, "loader",
         (AccumuloReloadingVFSClassLoader) null);
@@ -155,7 +150,7 @@ public class AccumuloVFSClassLoaderTest {
         (AccumuloReloadingVFSClassLoader) null);
 
     File conf = folder1.newFile("accumulo.properties");
-    FileWriter out = new FileWriter(conf);
+    FileWriter out = new FileWriter(conf, UTF_8);
     out.append("general.classpaths=\n");
     out.append("general.vfs.classpaths=\n");
     out.close();
@@ -191,7 +186,7 @@ public class AccumuloVFSClassLoaderTest {
     String cacheDir = "/some/random/cache/dir";
 
     File conf = folder1.newFile("accumulo.properties");
-    FileWriter out = new FileWriter(conf);
+    FileWriter out = new FileWriter(conf, UTF_8);
     out.append("general.classpaths=\n");
     out.append(AccumuloVFSClassLoader.VFS_CACHE_DIR + "=" + cacheDir + "\n");
     out.close();
