@@ -1,26 +1,28 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.functional;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.Collections.singletonMap;
-import static org.apache.accumulo.fate.util.UtilWaitThread.sleepUninterruptibly;
-import static org.junit.Assert.assertTrue;
+import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.time.Duration;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Random;
@@ -45,9 +47,9 @@ import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.test.TestIngest;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.io.Text;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -56,6 +58,11 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 public class LargeRowIT extends AccumuloClusterHarness {
   private static final Logger log = LoggerFactory.getLogger(LargeRowIT.class);
 
+  @Override
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(4);
+  }
+
   @Override
   public void configureMiniCluster(MiniAccumuloConfigImpl cfg, Configuration hadoopCoreSite) {
     cfg.setMemory(ServerType.TABLET_SERVER, cfg.getMemory(ServerType.TABLET_SERVER) * 2,
@@ -65,11 +72,6 @@ public class LargeRowIT extends AccumuloClusterHarness {
     cfg.setSiteConfig(siteConfig);
   }
 
-  @Override
-  protected int defaultTimeoutSeconds() {
-    return 4 * 60;
-  }
-
   private static final int SEED = 42;
   private static final int NUM_ROWS = 100;
   private static final int ROW_SIZE = 1 << 17;
@@ -81,7 +83,7 @@ public class LargeRowIT extends AccumuloClusterHarness {
   private int timeoutFactor = 1;
   private String tservMajcDelay;
 
-  @Before
+  @BeforeEach
   public void getTimeoutFactor() throws Exception {
     try {
       timeoutFactor = Integer.parseInt(System.getProperty("timeout.factor"));
@@ -90,7 +92,8 @@ public class LargeRowIT extends AccumuloClusterHarness {
           System.getProperty("timeout.factor"));
     }
 
-    assertTrue("Timeout factor must be greater than or equal to 1", timeoutFactor >= 1);
+    assertTrue(timeoutFactor >= 1,
+        "org.apache.accumulo.Timeout factor must be greater than or equal to 1");
 
     String[] names = getUniqueNames(2);
     REG_TABLE_NAME = names[0];
@@ -103,7 +106,7 @@ public class LargeRowIT extends AccumuloClusterHarness {
     }
   }
 
-  @After
+  @AfterEach
   public void resetMajcDelay() throws Exception {
     if (tservMajcDelay != null) {
       try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
@@ -112,16 +115,15 @@ public class LargeRowIT extends AccumuloClusterHarness {
     }
   }
 
-  @SuppressFBWarnings(value = "PREDICTABLE_RANDOM",
-      justification = "predictable random is okay for testing")
+  @SuppressFBWarnings(value = {"PREDICTABLE_RANDOM", "DMI_RANDOM_USED_ONLY_ONCE"},
+      justification = "predictable random with specific seed is intended for this test")
   @Test
   public void run() throws Exception {
-    Random r = new Random();
+    var random = new Random(SEED + 1);
     byte[] rowData = new byte[ROW_SIZE];
-    r.setSeed(SEED + 1);
     TreeSet<Text> splitPoints = new TreeSet<>();
     for (int i = 0; i < NUM_PRE_SPLITS; i++) {
-      r.nextBytes(rowData);
+      random.nextBytes(rowData);
       TestIngest.toPrintableChars(rowData);
       splitPoints.add(new Text(rowData));
     }
@@ -156,20 +158,19 @@ public class LargeRowIT extends AccumuloClusterHarness {
     basicTest(c, PRE_SPLIT_TABLE_NAME, NUM_PRE_SPLITS);
   }
 
-  @SuppressFBWarnings(value = "PREDICTABLE_RANDOM",
-      justification = "predictable random is okay for testing")
+  @SuppressFBWarnings(value = {"PREDICTABLE_RANDOM", "DMI_RANDOM_USED_ONLY_ONCE"},
+      justification = "predictable random with specific seed is intended for this test")
   private void basicTest(AccumuloClient c, String table, int expectedSplits) throws Exception {
     try (BatchWriter bw = c.createBatchWriter(table)) {
 
-      Random r = new Random();
+      var random = new Random(SEED);
       byte[] rowData = new byte[ROW_SIZE];
-      r.setSeed(SEED);
 
       for (int i = 0; i < NUM_ROWS; i++) {
-        r.nextBytes(rowData);
+        random.nextBytes(rowData);
         TestIngest.toPrintableChars(rowData);
         Mutation mut = new Mutation(new Text(rowData));
-        mut.put(new Text(""), new Text(""), new Value(Integer.toString(i).getBytes(UTF_8)));
+        mut.put("", "", Integer.toString(i));
         bw.addMutation(mut);
       }
     }
@@ -195,19 +196,17 @@ public class LargeRowIT extends AccumuloClusterHarness {
     FunctionalTestUtils.checkSplits(c, table, expectedSplits, expectedSplits);
   }
 
-  @SuppressFBWarnings(value = "PREDICTABLE_RANDOM",
-      justification = "predictable random is okay for testing")
+  @SuppressFBWarnings(value = {"PREDICTABLE_RANDOM", "DMI_RANDOM_USED_ONLY_ONCE"},
+      justification = "predictable random with specific seed is intended for this test")
   private void verify(AccumuloClient c, String table) throws Exception {
-    Random r = new Random();
+    var random = new Random(SEED);
     byte[] rowData = new byte[ROW_SIZE];
 
-    r.setSeed(SEED);
-
     try (Scanner scanner = c.createScanner(table, Authorizations.EMPTY)) {
 
       for (int i = 0; i < NUM_ROWS; i++) {
 
-        r.nextBytes(rowData);
+        random.nextBytes(rowData);
         TestIngest.toPrintableChars(rowData);
 
         scanner.setRange(new Range(new Text(rowData)));
@@ -218,7 +217,7 @@ public class LargeRowIT extends AccumuloClusterHarness {
           if (!entry.getKey().getRow().equals(new Text(rowData))) {
             throw new Exception("verification failed, unexpected row i =" + i);
           }
-          if (!entry.getValue().equals(new Value(Integer.toString(i).getBytes(UTF_8)))) {
+          if (!entry.getValue().equals(new Value(Integer.toString(i)))) {
             throw new Exception(
                 "verification failed, unexpected value i =" + i + " value = " + entry.getValue());
           }
