@@ -52,7 +52,7 @@ import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.Scanner;
-import org.apache.accumulo.core.client.admin.TableOperations;
+import org.apache.accumulo.core.client.sample.RowColumnSampler;
 import org.apache.accumulo.core.client.sample.RowSampler;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.KerberosToken;
@@ -79,6 +79,7 @@ import org.apache.accumulo.harness.SharedMiniClusterBase;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.test.compaction.TestCompactionStrategy;
 import org.apache.accumulo.test.functional.SlowIterator;
+import org.apache.accumulo.test.util.Wait;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -166,63 +167,93 @@ public class ShellServerIT extends SharedMiniClusterBase {
         getCluster().createAccumuloClient(getPrincipal(), new PasswordToken(getRootPassword()))) {
       client.securityOperations().grantNamespacePermission(getPrincipal(), "",
           NamespacePermission.ALTER_NAMESPACE);
-    }
 
-    final String table = getUniqueNames(1)[0];
-    final String table2 = table + "2";
+      final String tableBase = getUniqueNames(1)[0];
+      final String table = tableBase + "_export_src";
+      final String table2 = tableBase + "_import_tgt";
 
-    // exporttable / importtable
-    ts.exec("createtable " + table + " -evc", true);
-    make10();
-    ts.exec("addsplits row5", true);
-    ts.exec("config -t " + table + " -s table.split.threshold=345M", true);
-    ts.exec("offline " + table, true);
-    File exportDir = new File(rootPath, "ShellServerIT.export");
-    String exportUri = "file://" + exportDir;
-    String localTmp = "file://" + new File(rootPath, "ShellServerIT.tmp");
-    ts.exec("exporttable -t " + table + " " + exportUri, true);
-    DistCp cp = new DistCp(new Configuration(false), null);
-    String import_ = "file://" + new File(rootPath, "ShellServerIT.import");
-    ClientInfo info = ClientInfo.from(getCluster().getClientProperties());
-    if (info.saslEnabled()) {
-      // DistCp bugs out trying to get a fs delegation token to perform the cp. Just copy it
-      // ourselves by hand.
-      FileSystem fs = getCluster().getFileSystem();
-      FileSystem localFs = FileSystem.getLocal(new Configuration(false));
+      // exporttable / importtable
+      ts.exec("createtable " + table + " -evc", true);
+      make10();
+      ts.exec("addsplits row5", true);
+      ts.exec("config -t " + table + " -s table.split.threshold=345M", true);
+      ts.exec("offline " + table, true);
+      File exportDir = new File(rootPath, "ShellServerIT.export");
+      String exportUri = "file://" + exportDir;
+      String localTmp = "file://" + new File(rootPath, "ShellServerIT.tmp");
+      ts.exec("exporttable -t " + table + " " + exportUri, true);
+      DistCp cp = new DistCp(new Configuration(false), null);
+      String import_ = "file://" + new File(rootPath, "ShellServerIT.import");
+      ClientInfo info = ClientInfo.from(getCluster().getClientProperties());
+      if (info.saslEnabled()) {
+        // DistCp bugs out trying to get a fs delegation token to perform the cp. Just copy it
+        // ourselves by hand.
+        FileSystem fs = getCluster().getFileSystem();
+        FileSystem localFs = FileSystem.getLocal(new Configuration(false));
 
-      // Path on local fs to cp into
-      Path localTmpPath = new Path(localTmp);
-      localFs.mkdirs(localTmpPath);
+        // Path on local fs to cp into
+        Path localTmpPath = new Path(localTmp);
+        localFs.mkdirs(localTmpPath);
 
-      // Path in remote fs to importtable from
-      Path importDir = new Path(import_);
-      fs.mkdirs(importDir);
+        // Path in remote fs to importtable from
+        Path importDir = new Path(import_);
+        fs.mkdirs(importDir);
 
-      // Implement a poor-man's DistCp
-      try (BufferedReader reader =
-          new BufferedReader(new FileReader(new File(exportDir, "distcp.txt"), UTF_8))) {
-        for (String line; (line = reader.readLine()) != null;) {
-          Path exportedFile = new Path(line);
-          // There isn't a cp on FileSystem??
-          log.info("Copying {} to {}", line, localTmpPath);
-          fs.copyToLocalFile(exportedFile, localTmpPath);
-          Path tmpFile = new Path(localTmpPath, exportedFile.getName());
-          log.info("Moving {} to the import directory {}", tmpFile, importDir);
-          fs.moveFromLocalFile(tmpFile, importDir);
+        // Implement a poor-man's DistCp
+        try (BufferedReader reader =
+            new BufferedReader(new FileReader(new File(exportDir, "distcp.txt"), UTF_8))) {
+          for (String line; (line = reader.readLine()) != null;) {
+            Path exportedFile = new Path(line);
+            // There isn't a cp on FileSystem??
+            log.info("Copying {} to {}", line, localTmpPath);
+            fs.copyToLocalFile(exportedFile, localTmpPath);
+            Path tmpFile = new Path(localTmpPath, exportedFile.getName());
+            log.info("Moving {} to the import directory {}", tmpFile, importDir);
+            fs.moveFromLocalFile(tmpFile, importDir);
+          }
         }
+      } else {
+        String[] distCpArgs = {"-f", exportUri + "/distcp.txt", import_};
+        assertEquals(0, cp.run(distCpArgs), "Failed to run distcp: " + Arrays.toString(distCpArgs));
+      }
+      Thread.sleep(20);
+      ts.exec("importtable " + table2 + " " + import_, true);
+      ts.exec("config -t " + table2 + " -np", true, "345M", true);
+      ts.exec("getsplits -t " + table2, true, "row5", true);
+      ts.exec("constraint --list -t " + table2, true, "VisibilityConstraint=2", true);
+      ts.exec("online " + table, true);
+      ts.exec("deletetable -f " + table, true);
+      ts.exec("deletetable -f " + table2, true);
+    }
+  }
+
+  @Test
+  public void propStressTest() throws Exception {
+    try (AccumuloClient client =
+        getCluster().createAccumuloClient(getPrincipal(), new PasswordToken(getRootPassword()))) {
+      client.securityOperations().grantNamespacePermission(getPrincipal(), "",
+          NamespacePermission.ALTER_NAMESPACE);
+
+      final String table = getUniqueNames(1)[0];
+
+      ts.exec("createtable " + table + " -evc", true);
+      make10();
+      ts.exec("addsplits row5", true);
+
+      ts.exec("config -t " + table + " -s table.split.threshold=345M", true);
+      for (int i = 0; i < 50; i++) {
+        String expected = (100 + i) + "M";
+        ts.exec("config -t " + table + " -s table.split.threshold=" + expected, true);
+        ts.exec("config -t " + table + " -np -f table.split.threshold", true, expected, true);
+
+        ts.exec("config -t " + table + " -s table.scan.max.memory=" + expected, true);
+        ts.exec("config -t " + table + " -np -f table.scan.max.memory", true, expected, true);
+
+        String bExpected = ((i % 2) == 0) ? "true" : "false";
+        ts.exec("config -t " + table + " -s table.bloom.enabled=" + bExpected, true);
+        ts.exec("config -t " + table + " -np -f table.bloom.enabled", true, bExpected, true);
       }
-    } else {
-      String[] distCpArgs = {"-f", exportUri + "/distcp.txt", import_};
-      assertEquals(0, cp.run(distCpArgs), "Failed to run distcp: " + Arrays.toString(distCpArgs));
     }
-    ts.exec("importtable " + table2 + " " + import_, true);
-    Thread.sleep(100);
-    ts.exec("config -t " + table2 + " -np", true, "345M", true);
-    ts.exec("getsplits -t " + table2, true, "row5", true);
-    ts.exec("constraint --list -t " + table2, true, "VisibilityConstraint=2", true);
-    ts.exec("online " + table, true);
-    ts.exec("deletetable -f " + table, true);
-    ts.exec("deletetable -f " + table2, true);
   }
 
   @Test
@@ -425,8 +456,7 @@ public class ShellServerIT extends SharedMiniClusterBase {
 
       String expectedKey = "table.iterator.scan.cfcounter";
       String expectedValue = "30," + COLUMN_FAMILY_COUNTER_ITERATOR;
-      TableOperations tops = client.tableOperations();
-      checkTableForProperty(tops, tableName0, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName0, expectedKey, expectedValue);
 
       ts.exec("deletetable " + tableName0, true);
 
@@ -440,7 +470,7 @@ public class ShellServerIT extends SharedMiniClusterBase {
       ts.exec("setiter -scan -class " + COLUMN_FAMILY_COUNTER_ITERATOR + " -p 30", true);
       expectedKey = "table.iterator.scan.customcfcounter";
       expectedValue = "30," + COLUMN_FAMILY_COUNTER_ITERATOR;
-      checkTableForProperty(tops, tableName1, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName1, expectedKey, expectedValue);
 
       ts.exec("deletetable " + tableName1, true);
 
@@ -452,15 +482,16 @@ public class ShellServerIT extends SharedMiniClusterBase {
 
       // Name on the CLI should override OptionDescriber (or user input name, in this case)
       ts.exec("setiter -scan -class " + COLUMN_FAMILY_COUNTER_ITERATOR + " -p 30", true);
+
       expectedKey = "table.iterator.scan.customcfcounter";
       expectedValue = "30," + COLUMN_FAMILY_COUNTER_ITERATOR;
-      checkTableForProperty(tops, tableName2, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName2, expectedKey, expectedValue);
       expectedKey = "table.iterator.scan.customcfcounter.opt.name1";
       expectedValue = "value1";
-      checkTableForProperty(tops, tableName2, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName2, expectedKey, expectedValue);
       expectedKey = "table.iterator.scan.customcfcounter.opt.name2";
       expectedValue = "value2";
-      checkTableForProperty(tops, tableName2, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName2, expectedKey, expectedValue);
 
       ts.exec("deletetable " + tableName2, true);
 
@@ -475,33 +506,24 @@ public class ShellServerIT extends SharedMiniClusterBase {
           true);
       expectedKey = "table.iterator.scan.cfcounter";
       expectedValue = "30," + COLUMN_FAMILY_COUNTER_ITERATOR;
-      checkTableForProperty(tops, tableName3, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName3, expectedKey, expectedValue);
       expectedKey = "table.iterator.scan.cfcounter.opt.name1";
       expectedValue = "value1.1,value1.2,value1.3";
-      checkTableForProperty(tops, tableName3, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName3, expectedKey, expectedValue);
       expectedKey = "table.iterator.scan.cfcounter.opt.name2";
       expectedValue = "value2";
-      checkTableForProperty(tops, tableName3, expectedKey, expectedValue);
+      checkTableForProperty(client, tableName3, expectedKey, expectedValue);
 
       ts.exec("deletetable " + tableName3, true);
-
     }
   }
 
-  protected void checkTableForProperty(TableOperations tops, String tableName, String expectedKey,
-      String expectedValue) throws Exception {
-    for (int i = 0; i < 5; i++) {
-      for (Entry<String,String> entry : tops.getProperties(tableName)) {
-        if (expectedKey.equals(entry.getKey())) {
-          assertEquals(expectedValue, entry.getValue());
-          return;
-        }
-      }
-      Thread.sleep(500);
-    }
-
-    fail("Failed to find expected property on " + tableName + ": " + expectedKey + "="
-        + expectedValue);
+  protected void checkTableForProperty(final AccumuloClient client, final String tableName,
+      final String expectedKey, final String expectedValue) throws Exception {
+    assertTrue(
+        Wait.waitFor(() -> client.tableOperations().getConfiguration(tableName).get(expectedKey)
+            .equals(expectedValue), 5000, 500),
+        "Failed to find expected value for key: " + expectedKey);
   }
 
   @Test
@@ -710,14 +732,17 @@ public class ShellServerIT extends SharedMiniClusterBase {
 
     try (AccumuloClient accumuloClient = Accumulo.newClient().from(getClientProps()).build()) {
       accumuloClient.tableOperations().getConfiguration(table).forEach((key, value) -> {
-        if (key.equals("table.custom.description"))
+        if (key.equals("table.custom.description")) {
           assertEquals("description", value, "Initial property was not set correctly");
+        }
 
-        if (key.equals("table.custom.testProp"))
+        if (key.equals("table.custom.testProp")) {
           assertEquals("testProp", value, "Initial property was not set correctly");
+        }
 
-        if (key.equals(Property.TABLE_SPLIT_THRESHOLD.getKey()))
+        if (key.equals(Property.TABLE_SPLIT_THRESHOLD.getKey())) {
           assertEquals("10K", value, "Initial property was not set correctly");
+        }
       });
     }
     ts.exec("deletetable -f " + table);
@@ -898,7 +923,7 @@ public class ShellServerIT extends SharedMiniClusterBase {
   }
 
   @Test
-  public void testScanScample() throws Exception {
+  public void testScanSample() throws Exception {
     final String table = getUniqueNames(1)[0];
 
     // compact
@@ -926,7 +951,7 @@ public class ShellServerIT extends SharedMiniClusterBase {
     ts.exec("scan --sample", true, "accumulo", false);
     ts.exec("grep --sample acc", true, "accumulo", false);
 
-    // create table where table sample config differs from whats in file
+    // Create table where table sample config differs from what's in file
     String clone2 = table + "_clone_2";
     ts.exec("clonetable -s"
         + " table.sampler.opt.hasher=murmur3_32,table.sampler.opt.modulus=2,table.sampler="
@@ -947,6 +972,80 @@ public class ShellServerIT extends SharedMiniClusterBase {
     ts.exec("grep --sample 89", true, "8934", false);
   }
 
+  // Feb 2023 - the sample example utilizing RowColumnSampler was failing. Analysis found that
+  // the AbstractHashSampler was throwing an exception when additional options were utilized,
+  // i.e., options beyond the required base 'hasher' and 'modulus' options. Additionally, the
+  // RowColumnSampler threw an exception when the base options were parsed.
+  // This test exercises a sampler that utilizes additional options and verifies options are parsed
+  // successfully.
+  @Test
+  public void testScanSampleOptions() throws Exception {
+    final String table = getUniqueNames(1)[0];
+
+    ts.exec("createtable " + table);
+
+    ts.exec("insert 9255 doc content 'abcde'");
+    ts.exec("insert 9255 doc url file://foo.txt");
+    ts.exec("insert 8934 doc content 'accumulo scales'");
+    ts.exec("insert 8934 doc url file://accumulo_notes.txt");
+    ts.exec("insert 5454 image size 2024,800");
+    ts.exec("insert 7000 image metadata '2023/01/02 12:34:43'");
+    ts.exec("insert 7000 image uri file://image1.jpg");
+    ts.exec("insert 2317 doc content 'milk, eggs, bread, parmigiano-reggiano'");
+    ts.exec("insert 2317 doc url file://groceries/9.txt");
+    ts.exec("insert 3900 doc content 'EC2 ate my homework'");
+    ts.exec("insert 3900 doc url file://final_project.txt");
+
+    // Verify sampler with more than just base options parses correctly
+    String clone1 = table + "_clone_1";
+    ts.exec("clonetable -s"
+        + " table.sampler.opt.hasher=murmur3_32,table.sampler.opt.modulus=3,table.sampler.opt.qualifier="
+        + "true,table.sampler=" + RowColumnSampler.class.getName() + " " + table + " " + clone1);
+    ts.exec("compact -t " + clone1 + " -w --sf-no-sample");
+    ts.exec("table " + clone1);
+    ts.exec("scan --sample", true);
+    for (String expected : Arrays.asList("groceries", "final_project", "accumulo_notes",
+        "foo.txt")) {
+      ts.exec("scan --sample", true, expected, true);
+      ts.exec("grep --sample " + expected.substring(0, 2), true, expected, true);
+    }
+    for (String notExpected : Arrays.asList("bread", "homework", "scales", "abcde", "1024", "2023",
+        "image1")) {
+      ts.exec("scan --sample", true, notExpected, false);
+      ts.exec("grep --sample " + notExpected.substring(0, 2), true, notExpected, false);
+    }
+
+    // Verify failure to provide a base option results in empty sample result
+    String clone2 = table + "_clone_2";
+    ts.exec("clonetable -s table.sampler.opt.hasher=murmur3_32,table.sampler.opt.qualifier="
+        + "true,table.sampler=" + RowColumnSampler.class.getName() + " " + table + " " + clone2);
+    ts.exec("compact -t " + clone2 + " -w --sf-no-sample");
+    ts.exec("table " + clone2, true);
+    ts.exec("config -t " + clone2 + " -f sampler", true);
+    ts.exec("scan --sample", true);
+    // None of the expected rows/values should be returned from scan
+    for (String notExpected : Arrays.asList("2317", "3900", "5454", "7000", "8934", "9255")) {
+      ts.exec("scan --sample", true, notExpected, false);
+      ts.exec("grep --sample " + notExpected.substring(0, 3), true, notExpected, false);
+    }
+
+    // Verify providing an invalid option results in empty sample result
+    String clone3 = table + "_clone_3";
+    ts.exec("clonetable -s "
+        + "table.sampler.opt.hasher=murmur3_32,table.sampler.opt.modulus=5,table.sampler.opt.qualifier="
+        + "true,table.sampler.opt.badprop=42,table.sampler=" + RowColumnSampler.class.getName()
+        + " " + table + " " + clone3);
+    ts.exec("compact -t " + clone3 + " -w --sf-no-sample");
+    ts.exec("table " + clone3, true);
+    ts.exec("scan --sample", true);
+    // None of the expected rows/values should be returned from scan
+    for (String expected : Arrays.asList("2317", "3900", "5454", "7000", "8934", "9255")) {
+      ts.exec("scan --sample", true, expected, false);
+      ts.exec("grep --sample " + expected.substring(0, 3), true, expected, false);
+    }
+
+  }
+
   @Test
   public void constraint() throws Exception {
     final String table = getUniqueNames(1)[0];
@@ -1393,8 +1492,9 @@ public class ShellServerIT extends SharedMiniClusterBase {
     for (int i = 0; i < 10; i++) {
       ts.exec("ping", true, "OK", true);
       // wait for both tservers to start up
-      if (ts.output.get().split("\n").length == 3)
+      if (ts.output.get().split("\n").length == 3) {
         break;
+      }
       sleepUninterruptibly(1, TimeUnit.SECONDS);
 
     }
@@ -1823,8 +1923,7 @@ public class ShellServerIT extends SharedMiniClusterBase {
    * format that uses the current working table. Currently this test does not validate the actual
    * import - only the command syntax.
    *
-   * @throws Exception
-   *           any exception is a test failure.
+   * @throws Exception any exception is a test failure.
    */
   @Test
   public void importDirectoryCmdFmt() throws Exception {
