@@ -18,9 +18,11 @@
  */
 package org.apache.accumulo.test.start;
 
+import static java.util.stream.Collectors.toSet;
 import static org.apache.accumulo.harness.AccumuloITBase.SUNNY_DAY;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
@@ -55,6 +57,7 @@ import org.apache.accumulo.server.conf.CheckCompactionConfig;
 import org.apache.accumulo.server.conf.CheckServerConfig;
 import org.apache.accumulo.server.conf.util.ConfigPropertyUpgrader;
 import org.apache.accumulo.server.conf.util.ZooInfoViewer;
+import org.apache.accumulo.server.conf.util.ZooPropEditor;
 import org.apache.accumulo.server.init.Initialize;
 import org.apache.accumulo.server.util.Admin;
 import org.apache.accumulo.server.util.ConvertConfig;
@@ -81,12 +84,23 @@ public class KeywordStartIT {
 
   private final Logger log = LoggerFactory.getLogger(getClass());
 
+  /*
+   * Note: Tests below that use this method may be skipped if run in an IDE. That can happen if the
+   * services files haven't been generated by the AutoService annotation processor before this test
+   * runs. The AutoService annotation processor can be forced to run and generate those services
+   * files by running `mvn clean package -DskipTests` before importing the project into your IDE.
+   * There may be other ways to run annotation processors in your IDE, so this may not be necessary,
+   * depending on your IDE and its configuration.
+   */
+  private Map<String,KeywordExecutable> getKeywordExecutables() {
+    var all = Main.getExecutables(ClassLoader.getSystemClassLoader());
+    assumeTrue(!all.isEmpty());
+    return all;
+  }
+
   @Test
   public void testKeywordsMatch() {
-    for (Entry<String,KeywordExecutable> entry : Main.getExecutables(getClass().getClassLoader())
-        .entrySet()) {
-      assertEquals(entry.getKey(), entry.getValue().keyword());
-    }
+    getKeywordExecutables().forEach((k, v) -> assertEquals(k, v.keyword()));
   }
 
   @Test
@@ -109,12 +123,8 @@ public class KeywordStartIT {
    * This test guards against accidental renaming or incorrect naming of the keyword used to
    * identify the service. The keyword is used to access the commands via the command line, so
    * changes are visible to users and should not be changed.
-   * <p>
-   * Note: this test may fail in Eclipse, if the services files haven't been generated by the
-   * AutoService annotation processor
    */
   @Test
-  @SuppressWarnings("deprecation")
   public void testExpectedClasses() {
     assumeTrue(new File(System.getProperty("user.dir") + "/src").exists());
     TreeMap<String,Class<? extends KeywordExecutable>> expectSet = new TreeMap<>();
@@ -125,6 +135,7 @@ public class KeywordStartIT {
     expectSet.put("compactor", CompactorExecutable.class);
     expectSet.put("config-upgrade", ConfigPropertyUpgrader.class);
     expectSet.put("convert-config", ConvertConfig.class);
+    expectSet.put("create-empty", CreateEmpty.class);
     expectSet.put("create-token", CreateToken.class);
     expectSet.put("dump-zoo", DumpZookeeper.class);
     expectSet.put("ec-admin", ECAdmin.class);
@@ -135,25 +146,27 @@ public class KeywordStartIT {
     expectSet.put("init", Initialize.class);
     expectSet.put("login-info", LoginProperties.class);
     expectSet.put("manager", ManagerExecutable.class);
-    expectSet.put("master", org.apache.accumulo.manager.MasterExecutable.class);
     expectSet.put("minicluster", MiniClusterExecutable.class);
     expectSet.put("monitor", MonitorExecutable.class);
     expectSet.put("rfile-info", PrintInfo.class);
-    expectSet.put("wal-info", LogReader.class);
     expectSet.put("shell", Shell.class);
-    expectSet.put("tserver", TServerExecutable.class);
-    expectSet.put("version", Version.class);
-    expectSet.put("zookeeper", ZooKeeperMain.class);
-    expectSet.put("create-empty", CreateEmpty.class);
     expectSet.put("split-large", SplitLarge.class);
     expectSet.put("sserver", ScanServerExecutable.class);
+    expectSet.put("tserver", TServerExecutable.class);
+    expectSet.put("version", Version.class);
+    expectSet.put("wal-info", LogReader.class);
     expectSet.put("zoo-info-viewer", ZooInfoViewer.class);
+    expectSet.put("zoo-prop-editor", ZooPropEditor.class);
     expectSet.put("zoo-zap", ZooZap.class);
+    expectSet.put("zookeeper", ZooKeeperMain.class);
+
+    @SuppressWarnings("deprecation")
+    var masterExecutableClass = org.apache.accumulo.manager.MasterExecutable.class;
+    expectSet.put("master", masterExecutableClass);
 
     Iterator<Entry<String,Class<? extends KeywordExecutable>>> expectIter =
         expectSet.entrySet().iterator();
-    TreeMap<String,KeywordExecutable> actualSet =
-        new TreeMap<>(Main.getExecutables(getClass().getClassLoader()));
+    TreeMap<String,KeywordExecutable> actualSet = new TreeMap<>(getKeywordExecutables());
     Iterator<Entry<String,KeywordExecutable>> actualIter = actualSet.entrySet().iterator();
     Entry<String,Class<? extends KeywordExecutable>> expected;
     Entry<String,KeywordExecutable> actual;
@@ -179,8 +192,12 @@ public class KeywordStartIT {
     assertFalse(moreActual, "Found additional unexpected classes");
   }
 
+  /**
+   * This test validates that legacy tools that had a main method that the main method is not
+   * removed to support user scripts that may use that main method. New utilities should refrain
+   * from adding a main method and instead rely on the ServiceLoader capability.
+   */
   @Test
-  @SuppressWarnings("deprecation")
   public void checkHasMain() {
     assertFalse(hasMain(this.getClass()),
         "Sanity check for test failed. Somehow the test class has a main method");
@@ -188,25 +205,50 @@ public class KeywordStartIT {
     HashSet<Class<?>> expectSet = new HashSet<>();
     expectSet.add(Admin.class);
     expectSet.add(CheckCompactionConfig.class);
+    expectSet.add(CheckServerConfig.class);
+    expectSet.add(ConfigPropertyUpgrader.class);
+    expectSet.add(ConvertConfig.class);
+    expectSet.add(CreateEmpty.class);
     expectSet.add(CreateToken.class);
     expectSet.add(DumpZookeeper.class);
+    expectSet.add(ECAdmin.class);
+    expectSet.add(GenerateSplits.class);
     expectSet.add(Info.class);
     expectSet.add(Initialize.class);
+    expectSet.add(LogReader.class);
     expectSet.add(LoginProperties.class);
-    expectSet.add(org.apache.accumulo.master.Master.class);
     expectSet.add(MiniAccumuloRunner.class);
     expectSet.add(Monitor.class);
     expectSet.add(PrintInfo.class);
-    expectSet.add(LogReader.class);
     expectSet.add(Shell.class);
     expectSet.add(SimpleGarbageCollector.class);
+    expectSet.add(SplitLarge.class);
     expectSet.add(TabletServer.class);
     expectSet.add(ZooKeeperMain.class);
+    expectSet.add(ZooZap.class);
 
-    for (Class<?> c : expectSet) {
-      assertTrue(hasMain(c), "Class " + c.getName() + " is missing a main method!");
-    }
+    // not a KeywordExecutable, but this is known to have a main method
+    @SuppressWarnings("deprecation")
+    var masterClass = org.apache.accumulo.master.Master.class;
+    expectSet.add(masterClass);
 
+    // check that classes in the expected set contain a main
+    // not all have them; these do because they always have, and we don't want to break things
+    expectSet.forEach(
+        c -> assertTrue(hasMain(c), "Class " + c.getName() + " is missing a main method!"));
+
+    // build a list of all classed that implement KeywordExecutable
+    var all = getKeywordExecutables().values().stream().map(Object::getClass).collect(toSet());
+
+    // remove the ones we already verified have a main method
+    assertTrue(all.removeAll(expectSet));
+
+    // ensure there's still some left (there should be some that don't have a main method)
+    assertNotEquals(0, all.size());
+
+    // for those remaining, make sure they *don't* have an unexpected main method
+    all.forEach(
+        c -> assertFalse(hasMain(c), "Class " + c.getName() + " has an unexpected main method!"));
   }
 
   private static boolean hasMain(Class<?> classToCheck) {
